# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models_py3 import (  # type: ignore
    AadAuthenticationParameters,
    Action,
    ActiveBaseSecurityAdminRule,
    ActiveConfigurationParameter,
    ActiveConnectivityConfiguration,
    ActiveConnectivityConfigurationsListResult,
    ActiveDefaultSecurityAdminRule,
    ActiveSecurityAdminRule,
    ActiveSecurityAdminRulesListResult,
    AddressPrefixItem,
    AddressSpace,
    AdminRule,
    AdminRuleCollection,
    AdminRuleCollectionListResult,
    AdminRuleListResult,
    AdvertisedPublicPrefixProperties,
    ApplicationGateway,
    ApplicationGatewayAuthenticationCertificate,
    ApplicationGatewayAutoscaleConfiguration,
    ApplicationGatewayAvailableSslOptions,
    ApplicationGatewayAvailableSslPredefinedPolicies,
    ApplicationGatewayAvailableWafRuleSetsResult,
    ApplicationGatewayBackendAddress,
    ApplicationGatewayBackendAddressPool,
    ApplicationGatewayBackendHealth,
    ApplicationGatewayBackendHealthHttpSettings,
    ApplicationGatewayBackendHealthOnDemand,
    ApplicationGatewayBackendHealthPool,
    ApplicationGatewayBackendHealthServer,
    ApplicationGatewayBackendHttpSettings,
    ApplicationGatewayBackendSettings,
    ApplicationGatewayClientAuthConfiguration,
    ApplicationGatewayConnectionDraining,
    ApplicationGatewayCustomError,
    ApplicationGatewayFirewallDisabledRuleGroup,
    ApplicationGatewayFirewallExclusion,
    ApplicationGatewayFirewallManifestRuleSet,
    ApplicationGatewayFirewallRule,
    ApplicationGatewayFirewallRuleGroup,
    ApplicationGatewayFirewallRuleSet,
    ApplicationGatewayForContainersReferenceDefinition,
    ApplicationGatewayFrontendIPConfiguration,
    ApplicationGatewayFrontendPort,
    ApplicationGatewayGlobalConfiguration,
    ApplicationGatewayHeaderConfiguration,
    ApplicationGatewayHttpListener,
    ApplicationGatewayIPConfiguration,
    ApplicationGatewayListResult,
    ApplicationGatewayListener,
    ApplicationGatewayLoadDistributionPolicy,
    ApplicationGatewayLoadDistributionTarget,
    ApplicationGatewayOnDemandProbe,
    ApplicationGatewayPathRule,
    ApplicationGatewayPrivateEndpointConnection,
    ApplicationGatewayPrivateEndpointConnectionListResult,
    ApplicationGatewayPrivateLinkConfiguration,
    ApplicationGatewayPrivateLinkIpConfiguration,
    ApplicationGatewayPrivateLinkResource,
    ApplicationGatewayPrivateLinkResourceListResult,
    ApplicationGatewayProbe,
    ApplicationGatewayProbeHealthResponseMatch,
    ApplicationGatewayRedirectConfiguration,
    ApplicationGatewayRequestRoutingRule,
    ApplicationGatewayRewriteRule,
    ApplicationGatewayRewriteRuleActionSet,
    ApplicationGatewayRewriteRuleCondition,
    ApplicationGatewayRewriteRuleSet,
    ApplicationGatewayRoutingRule,
    ApplicationGatewaySku,
    ApplicationGatewaySslCertificate,
    ApplicationGatewaySslPolicy,
    ApplicationGatewaySslPredefinedPolicy,
    ApplicationGatewaySslProfile,
    ApplicationGatewayTrustedClientCertificate,
    ApplicationGatewayTrustedRootCertificate,
    ApplicationGatewayUrlConfiguration,
    ApplicationGatewayUrlPathMap,
    ApplicationGatewayWafDynamicManifestResult,
    ApplicationGatewayWafDynamicManifestResultList,
    ApplicationGatewayWebApplicationFirewallConfiguration,
    ApplicationRule,
    ApplicationSecurityGroup,
    ApplicationSecurityGroupListResult,
    AuthorizationListResult,
    AutoApprovedPrivateLinkService,
    AutoApprovedPrivateLinkServicesResult,
    Availability,
    AvailableDelegation,
    AvailableDelegationsResult,
    AvailablePrivateEndpointType,
    AvailablePrivateEndpointTypesResult,
    AvailableProvidersList,
    AvailableProvidersListCity,
    AvailableProvidersListCountry,
    AvailableProvidersListParameters,
    AvailableProvidersListState,
    AvailableServiceAlias,
    AvailableServiceAliasesResult,
    AzureAsyncOperationResult,
    AzureFirewall,
    AzureFirewallApplicationRule,
    AzureFirewallApplicationRuleCollection,
    AzureFirewallApplicationRuleProtocol,
    AzureFirewallAutoscaleConfiguration,
    AzureFirewallFqdnTag,
    AzureFirewallFqdnTagListResult,
    AzureFirewallIPConfiguration,
    AzureFirewallIpGroups,
    AzureFirewallListResult,
    AzureFirewallNatRCAction,
    AzureFirewallNatRule,
    AzureFirewallNatRuleCollection,
    AzureFirewallNetworkRule,
    AzureFirewallNetworkRuleCollection,
    AzureFirewallPacketCaptureFlags,
    AzureFirewallPacketCaptureRule,
    AzureFirewallPublicIPAddress,
    AzureFirewallRCAction,
    AzureFirewallSku,
    AzureReachabilityReport,
    AzureReachabilityReportItem,
    AzureReachabilityReportLatencyInfo,
    AzureReachabilityReportLocation,
    AzureReachabilityReportParameters,
    AzureWebCategory,
    AzureWebCategoryListResult,
    BGPCommunity,
    BackendAddressInboundNatRulePortMappings,
    BackendAddressPool,
    BaseAdminRule,
    BastionActiveSession,
    BastionActiveSessionListResult,
    BastionHost,
    BastionHostIPConfiguration,
    BastionHostListResult,
    BastionHostPropertiesFormatNetworkAcls,
    BastionSessionDeleteResult,
    BastionSessionState,
    BastionShareableLink,
    BastionShareableLinkListRequest,
    BastionShareableLinkListResult,
    BastionShareableLinkTokenListRequest,
    BgpConnection,
    BgpPeerStatus,
    BgpPeerStatusListResult,
    BgpServiceCommunity,
    BgpServiceCommunityListResult,
    BgpSettings,
    BreakOutCategoryPolicies,
    CheckPrivateLinkServiceVisibilityRequest,
    ChildResource,
    CircuitMetadataMap,
    CloudErrorBody,
    CommonErrorAdditionalInfo,
    CommonErrorDetail,
    CommonErrorResponse,
    CommonProxyResource,
    CommonResource,
    CommonTrackedResource,
    Components1Jq1T4ISchemasManagedserviceidentityPropertiesUserassignedidentitiesAdditionalproperties,
    ConfigurationGroup,
    ConnectionMonitor,
    ConnectionMonitorDestination,
    ConnectionMonitorEndpoint,
    ConnectionMonitorEndpointFilter,
    ConnectionMonitorEndpointFilterItem,
    ConnectionMonitorEndpointLocationDetails,
    ConnectionMonitorEndpointScope,
    ConnectionMonitorEndpointScopeItem,
    ConnectionMonitorHttpConfiguration,
    ConnectionMonitorIcmpConfiguration,
    ConnectionMonitorListResult,
    ConnectionMonitorOutput,
    ConnectionMonitorParameters,
    ConnectionMonitorQueryResult,
    ConnectionMonitorResult,
    ConnectionMonitorResultProperties,
    ConnectionMonitorSource,
    ConnectionMonitorSuccessThreshold,
    ConnectionMonitorTcpConfiguration,
    ConnectionMonitorTestConfiguration,
    ConnectionMonitorTestGroup,
    ConnectionMonitorWorkspaceSettings,
    ConnectionResetSharedKey,
    ConnectionSharedKey,
    ConnectionSharedKeyResult,
    ConnectionSharedKeyResultList,
    ConnectionStateSnapshot,
    ConnectivityConfiguration,
    ConnectivityConfigurationListResult,
    ConnectivityConfigurationPropertiesConnectivityCapabilities,
    ConnectivityDestination,
    ConnectivityGroupItem,
    ConnectivityHop,
    ConnectivityInformation,
    ConnectivityIssue,
    ConnectivityParameters,
    ConnectivitySource,
    Container,
    ContainerNetworkInterface,
    ContainerNetworkInterfaceConfiguration,
    ContainerNetworkInterfaceIpConfiguration,
    Criterion,
    CrossTenantScopes,
    CustomDnsConfigPropertiesFormat,
    CustomIpPrefix,
    CustomIpPrefixListResult,
    DdosCustomPolicy,
    DdosProtectionPlan,
    DdosProtectionPlanListResult,
    DdosSettings,
    DefaultAdminRule,
    Delegation,
    DelegationProperties,
    DeviceProperties,
    DhcpOptions,
    Dimension,
    DnsNameAvailabilityResult,
    DnsSettings,
    DscpConfiguration,
    DscpConfigurationListResult,
    EffectiveBaseSecurityAdminRule,
    EffectiveConnectivityConfiguration,
    EffectiveDefaultSecurityAdminRule,
    EffectiveNetworkSecurityGroup,
    EffectiveNetworkSecurityGroupAssociation,
    EffectiveNetworkSecurityGroupListResult,
    EffectiveNetworkSecurityRule,
    EffectiveRoute,
    EffectiveRouteListResult,
    EffectiveRouteMapRoute,
    EffectiveRouteMapRouteList,
    EffectiveRoutesParameters,
    EffectiveSecurityAdminRule,
    EndpointServiceResult,
    EndpointServicesListResult,
    Error,
    ErrorAdditionalInfo,
    ErrorDetail,
    ErrorDetails,
    ErrorResponse,
    EvaluatedNetworkSecurityGroup,
    ExceptionEntry,
    ExclusionManagedRule,
    ExclusionManagedRuleGroup,
    ExclusionManagedRuleSet,
    ExplicitProxy,
    ExpressRouteCircuit,
    ExpressRouteCircuitArpTable,
    ExpressRouteCircuitAuthorization,
    ExpressRouteCircuitConnection,
    ExpressRouteCircuitConnectionListResult,
    ExpressRouteCircuitListResult,
    ExpressRouteCircuitPeering,
    ExpressRouteCircuitPeeringConfig,
    ExpressRouteCircuitPeeringId,
    ExpressRouteCircuitPeeringListResult,
    ExpressRouteCircuitReference,
    ExpressRouteCircuitRoutesTable,
    ExpressRouteCircuitRoutesTableSummary,
    ExpressRouteCircuitServiceProviderProperties,
    ExpressRouteCircuitSku,
    ExpressRouteCircuitStats,
    ExpressRouteCircuitsArpTableListResult,
    ExpressRouteCircuitsRoutesTableListResult,
    ExpressRouteCircuitsRoutesTableSummaryListResult,
    ExpressRouteConnection,
    ExpressRouteConnectionId,
    ExpressRouteConnectionList,
    ExpressRouteCrossConnection,
    ExpressRouteCrossConnectionListResult,
    ExpressRouteCrossConnectionPeering,
    ExpressRouteCrossConnectionPeeringList,
    ExpressRouteCrossConnectionRoutesTableSummary,
    ExpressRouteCrossConnectionsRoutesTableSummaryListResult,
    ExpressRouteFailoverCircuitResourceDetails,
    ExpressRouteFailoverConnectionResourceDetails,
    ExpressRouteFailoverRedundantRoute,
    ExpressRouteFailoverSingleTestDetails,
    ExpressRouteFailoverStopApiParameters,
    ExpressRouteFailoverTestDetails,
    ExpressRouteGateway,
    ExpressRouteGatewayList,
    ExpressRouteGatewayPropertiesAutoScaleConfiguration,
    ExpressRouteGatewayPropertiesAutoScaleConfigurationBounds,
    ExpressRouteLink,
    ExpressRouteLinkListResult,
    ExpressRouteLinkMacSecConfig,
    ExpressRoutePort,
    ExpressRoutePortAuthorization,
    ExpressRoutePortAuthorizationListResult,
    ExpressRoutePortListResult,
    ExpressRoutePortsLocation,
    ExpressRoutePortsLocationBandwidths,
    ExpressRoutePortsLocationListResult,
    ExpressRouteProviderPort,
    ExpressRouteProviderPortListResult,
    ExpressRouteServiceProvider,
    ExpressRouteServiceProviderBandwidthsOffered,
    ExpressRouteServiceProviderListResult,
    ExtendedLocation,
    FailoverConnectionDetails,
    FilterItems,
    FirewallPacketCaptureParameters,
    FirewallPolicy,
    FirewallPolicyCertificateAuthority,
    FirewallPolicyDraft,
    FirewallPolicyFilterRuleCollection,
    FirewallPolicyFilterRuleCollectionAction,
    FirewallPolicyHttpHeaderToInsert,
    FirewallPolicyInsights,
    FirewallPolicyIntrusionDetection,
    FirewallPolicyIntrusionDetectionBypassTrafficSpecifications,
    FirewallPolicyIntrusionDetectionConfiguration,
    FirewallPolicyIntrusionDetectionSignatureSpecification,
    FirewallPolicyListResult,
    FirewallPolicyLogAnalyticsResources,
    FirewallPolicyLogAnalyticsWorkspace,
    FirewallPolicyNatRuleCollection,
    FirewallPolicyNatRuleCollectionAction,
    FirewallPolicyRule,
    FirewallPolicyRuleApplicationProtocol,
    FirewallPolicyRuleCollection,
    FirewallPolicyRuleCollectionGroup,
    FirewallPolicyRuleCollectionGroupDraft,
    FirewallPolicyRuleCollectionGroupListResult,
    FirewallPolicySNAT,
    FirewallPolicySQL,
    FirewallPolicySku,
    FirewallPolicyThreatIntelWhitelist,
    FirewallPolicyTransportSecurity,
    FlowLog,
    FlowLogFormatParameters,
    FlowLogInformation,
    FlowLogListResult,
    FlowLogStatusParameters,
    FrontendIPConfiguration,
    GatewayCustomBgpIpAddressIpConfiguration,
    GatewayLoadBalancerTunnelInterface,
    GatewayResiliencyInformation,
    GatewayResiliencyRecommendation,
    GatewayRoute,
    GatewayRouteListResult,
    GatewayRouteSet,
    GatewayRouteSetsInformation,
    GenerateExpressRoutePortsLOARequest,
    GenerateExpressRoutePortsLOAResult,
    GetInboundRoutesParameters,
    GetOutboundRoutesParameters,
    GetVpnSitesConfigurationRequest,
    GroupByUserSession,
    GroupByVariable,
    HTTPConfiguration,
    HTTPHeader,
    HeaderValueMatcher,
    HopLink,
    Hub,
    HubIPAddresses,
    HubIpConfiguration,
    HubPublicIPAddresses,
    HubRoute,
    HubRouteTable,
    HubVirtualNetworkConnection,
    IDPSQueryObject,
    IPAddressAvailabilityResult,
    IPConfiguration,
    IPConfigurationBgpPeeringAddress,
    IPConfigurationProfile,
    IPPrefixesList,
    IPRule,
    IPTraffic,
    InboundNatPool,
    InboundNatRule,
    InboundNatRuleListResult,
    InboundNatRulePortMapping,
    InboundSecurityRule,
    InboundSecurityRules,
    IntentContent,
    InternetIngressPublicIpsProperties,
    IpAllocation,
    IpAllocationListResult,
    IpGroup,
    IpGroupListResult,
    IpTag,
    IpamPool,
    IpamPoolList,
    IpamPoolPrefixAllocation,
    IpamPoolProperties,
    IpamPoolUpdate,
    IpamPoolUpdateProperties,
    IpsecPolicy,
    Ipv6CircuitConnectionConfig,
    Ipv6ExpressRouteCircuitPeeringConfig,
    ListHubRouteTablesResult,
    ListHubVirtualNetworkConnectionsResult,
    ListP2SVpnGatewaysResult,
    ListRouteMapsResult,
    ListRoutingIntentResult,
    ListVirtualHubBgpConnectionResults,
    ListVirtualHubIpConfigurationResults,
    ListVirtualHubRouteTableV2SResult,
    ListVirtualHubsResult,
    ListVirtualNetworkGatewayNatRulesResult,
    ListVirtualWANsResult,
    ListVpnConnectionsResult,
    ListVpnGatewayNatRulesResult,
    ListVpnGatewaysResult,
    ListVpnServerConfigurationPolicyGroupsResult,
    ListVpnServerConfigurationsResult,
    ListVpnSiteLinkConnectionsResult,
    ListVpnSiteLinksResult,
    ListVpnSitesResult,
    LoadBalancer,
    LoadBalancerBackendAddress,
    LoadBalancerBackendAddressPoolListResult,
    LoadBalancerFrontendIPConfigurationListResult,
    LoadBalancerHealthPerRule,
    LoadBalancerHealthPerRulePerBackendAddress,
    LoadBalancerListResult,
    LoadBalancerLoadBalancingRuleListResult,
    LoadBalancerOutboundRuleListResult,
    LoadBalancerProbeListResult,
    LoadBalancerSku,
    LoadBalancerVipSwapRequest,
    LoadBalancerVipSwapRequestFrontendIPConfiguration,
    LoadBalancingRule,
    LocalNetworkGateway,
    LocalNetworkGatewayListResult,
    LogSpecification,
    ManagedRuleGroupOverride,
    ManagedRuleOverride,
    ManagedRuleSet,
    ManagedRuleSetRuleGroup,
    ManagedRulesDefinition,
    ManagedServiceIdentity,
    MatchCondition,
    MatchVariable,
    MatchedRule,
    MetricSpecification,
    MigrateLoadBalancerToIpBasedRequest,
    MigratedPools,
    NatGateway,
    NatGatewayListResult,
    NatGatewaySku,
    NatRule,
    NatRulePortMapping,
    NetworkConfigurationDiagnosticParameters,
    NetworkConfigurationDiagnosticProfile,
    NetworkConfigurationDiagnosticResponse,
    NetworkConfigurationDiagnosticResult,
    NetworkGroup,
    NetworkGroupListResult,
    NetworkIntentPolicy,
    NetworkIntentPolicyConfiguration,
    NetworkInterface,
    NetworkInterfaceAssociation,
    NetworkInterfaceDnsSettings,
    NetworkInterfaceIPConfiguration,
    NetworkInterfaceIPConfigurationListResult,
    NetworkInterfaceIPConfigurationPrivateLinkConnectionProperties,
    NetworkInterfaceListResult,
    NetworkInterfaceLoadBalancerListResult,
    NetworkInterfaceTapConfiguration,
    NetworkInterfaceTapConfigurationListResult,
    NetworkManager,
    NetworkManagerCommit,
    NetworkManagerConnection,
    NetworkManagerConnectionListResult,
    NetworkManagerDeploymentStatus,
    NetworkManagerDeploymentStatusListResult,
    NetworkManagerDeploymentStatusParameter,
    NetworkManagerEffectiveConnectivityConfigurationListResult,
    NetworkManagerEffectiveSecurityAdminRulesListResult,
    NetworkManagerListResult,
    NetworkManagerPropertiesNetworkManagerScopes,
    NetworkManagerRoutingConfiguration,
    NetworkManagerRoutingConfigurationListResult,
    NetworkManagerRoutingGroupItem,
    NetworkManagerSecurityGroupItem,
    NetworkProfile,
    NetworkProfileListResult,
    NetworkRule,
    NetworkSecurityGroup,
    NetworkSecurityGroupListResult,
    NetworkSecurityGroupResult,
    NetworkSecurityPerimeter,
    NetworkSecurityPerimeterListResult,
    NetworkSecurityRulesEvaluationResult,
    NetworkVirtualAppliance,
    NetworkVirtualApplianceBootDiagnosticParameters,
    NetworkVirtualApplianceConnection,
    NetworkVirtualApplianceConnectionList,
    NetworkVirtualApplianceInstanceId,
    NetworkVirtualApplianceInstanceIds,
    NetworkVirtualApplianceListResult,
    NetworkVirtualAppliancePropertiesFormatNetworkProfile,
    NetworkVirtualApplianceSiteListResult,
    NetworkVirtualApplianceSku,
    NetworkVirtualApplianceSkuInstances,
    NetworkVirtualApplianceSkuListResult,
    NetworkWatcher,
    NetworkWatcherListResult,
    NextHopParameters,
    NextHopResult,
    NspAccessRule,
    NspAccessRuleListResult,
    NspAssociation,
    NspAssociationsListResult,
    NspLink,
    NspLinkListResult,
    NspLinkReference,
    NspLinkReferenceListResult,
    NspLoggingConfiguration,
    NspLoggingConfigurationListResult,
    NspProfile,
    NspProfileListResult,
    O365BreakOutCategoryPolicies,
    O365PolicyProperties,
    Office365PolicyProperties,
    Operation,
    OperationDisplay,
    OperationListResult,
    OperationPropertiesFormatServiceSpecification,
    OperationStatusResult,
    OrderBy,
    OutboundRule,
    OwaspCrsExclusionEntry,
    P2SConnectionConfiguration,
    P2SVpnConnectionHealth,
    P2SVpnConnectionHealthRequest,
    P2SVpnConnectionRequest,
    P2SVpnGateway,
    P2SVpnProfileParameters,
    PacketCapture,
    PacketCaptureFilter,
    PacketCaptureListResult,
    PacketCaptureMachineScope,
    PacketCaptureParameters,
    PacketCaptureQueryStatusResult,
    PacketCaptureResult,
    PacketCaptureResultProperties,
    PacketCaptureSettings,
    PacketCaptureStorageLocation,
    Parameter,
    PartnerManagedResourceProperties,
    PatchObject,
    PatchRouteFilter,
    PatchRouteFilterRule,
    PeerExpressRouteCircuitConnection,
    PeerExpressRouteCircuitConnectionListResult,
    PeerRoute,
    PerimeterAssociableResource,
    PerimeterAssociableResourcesListResult,
    PerimeterBasedAccessRule,
    PolicySettings,
    PolicySettingsLogScrubbing,
    PoolAssociation,
    PoolAssociationList,
    PoolUsage,
    PrepareNetworkPoliciesRequest,
    PrivateDnsZoneConfig,
    PrivateDnsZoneGroup,
    PrivateDnsZoneGroupListResult,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionListResult,
    PrivateEndpointIPConfiguration,
    PrivateEndpointListResult,
    PrivateLinkService,
    PrivateLinkServiceConnection,
    PrivateLinkServiceConnectionState,
    PrivateLinkServiceIpConfiguration,
    PrivateLinkServiceListResult,
    PrivateLinkServicePropertiesAutoApproval,
    PrivateLinkServicePropertiesVisibility,
    PrivateLinkServiceVisibility,
    Probe,
    PropagatedRouteTable,
    ProtocolConfiguration,
    ProxyResource,
    PublicIPAddress,
    PublicIPAddressDnsSettings,
    PublicIPAddressListResult,
    PublicIPAddressSku,
    PublicIPPrefix,
    PublicIPPrefixListResult,
    PublicIPPrefixSku,
    PublicIpDdosProtectionStatusResult,
    QosDefinition,
    QosIpRange,
    QosPortRange,
    QueryInboundNatRulePortMappingRequest,
    QueryRequestOptions,
    QueryResults,
    QueryTroubleshootingParameters,
    RadiusServer,
    ReachabilityAnalysisIntent,
    ReachabilityAnalysisIntentListResult,
    ReachabilityAnalysisIntentProperties,
    ReachabilityAnalysisRun,
    ReachabilityAnalysisRunListResult,
    ReachabilityAnalysisRunProperties,
    RecordSet,
    ReferencedPublicIpAddress,
    ResiliencyRecommendationComponents,
    Resource,
    ResourceBasics,
    ResourceNavigationLink,
    ResourceNavigationLinksListResult,
    ResourceSet,
    RetentionPolicyParameters,
    Route,
    RouteFilter,
    RouteFilterListResult,
    RouteFilterRule,
    RouteFilterRuleListResult,
    RouteListResult,
    RouteMap,
    RouteMapRule,
    RouteSourceDetails,
    RouteTable,
    RouteTableListResult,
    RoutingConfiguration,
    RoutingIntent,
    RoutingPolicy,
    RoutingRule,
    RoutingRuleCollection,
    RoutingRuleCollectionListResult,
    RoutingRuleListResult,
    RoutingRuleNextHop,
    RoutingRuleRouteDestination,
    ScopeConnection,
    ScopeConnectionListResult,
    SecurityAdminConfiguration,
    SecurityAdminConfigurationListResult,
    SecurityGroupNetworkInterface,
    SecurityGroupViewParameters,
    SecurityGroupViewResult,
    SecurityPartnerProvider,
    SecurityPartnerProviderListResult,
    SecurityPerimeterProxyResource,
    SecurityPerimeterResource,
    SecurityPerimeterSystemData,
    SecurityRule,
    SecurityRuleAssociations,
    SecurityRuleListResult,
    SecurityUserConfiguration,
    SecurityUserConfigurationListResult,
    SecurityUserGroupItem,
    SecurityUserRule,
    SecurityUserRuleCollection,
    SecurityUserRuleCollectionListResult,
    SecurityUserRuleListResult,
    ServiceAssociationLink,
    ServiceAssociationLinksListResult,
    ServiceEndpointPolicy,
    ServiceEndpointPolicyDefinition,
    ServiceEndpointPolicyDefinitionListResult,
    ServiceEndpointPolicyListResult,
    ServiceEndpointPropertiesFormat,
    ServiceTagInformation,
    ServiceTagInformationListResult,
    ServiceTagInformationPropertiesFormat,
    ServiceTagsListResult,
    SessionIds,
    SharedKeyProperties,
    SignatureOverridesFilterValuesQuery,
    SignatureOverridesFilterValuesResponse,
    SignaturesOverrides,
    SignaturesOverridesList,
    SignaturesOverridesProperties,
    SingleQueryResult,
    Sku,
    StaticCidr,
    StaticCidrList,
    StaticCidrProperties,
    StaticMember,
    StaticMemberListResult,
    StaticRoute,
    StaticRoutesConfig,
    SubResource,
    Subnet,
    SubnetAssociation,
    SubnetListResult,
    SubscriptionId,
    SwapResource,
    SwapResourceListResult,
    SwapResourceProperties,
    SystemData,
    TagsObject,
    Topology,
    TopologyAssociation,
    TopologyParameters,
    TopologyResource,
    TrackedResource,
    TrafficAnalyticsConfigurationProperties,
    TrafficAnalyticsProperties,
    TrafficSelectorPolicy,
    TroubleshootingDetails,
    TroubleshootingParameters,
    TroubleshootingRecommendedActions,
    TroubleshootingResult,
    TunnelConnectionHealth,
    UnprepareNetworkPoliciesRequest,
    UpdateTagsRequest,
    Usage,
    UsageName,
    UsagesListResult,
    VM,
    VerificationIPFlowParameters,
    VerificationIPFlowResult,
    VerifierWorkspace,
    VerifierWorkspaceListResult,
    VerifierWorkspaceProperties,
    VerifierWorkspaceUpdate,
    VerifierWorkspaceUpdateProperties,
    VirtualApplianceAdditionalNicProperties,
    VirtualApplianceIPConfiguration,
    VirtualApplianceIPConfigurationProperties,
    VirtualApplianceNetworkInterfaceConfiguration,
    VirtualApplianceNetworkInterfaceConfigurationProperties,
    VirtualApplianceNicProperties,
    VirtualApplianceSite,
    VirtualApplianceSkuProperties,
    VirtualHub,
    VirtualHubEffectiveRoute,
    VirtualHubEffectiveRouteList,
    VirtualHubId,
    VirtualHubRoute,
    VirtualHubRouteTable,
    VirtualHubRouteTableV2,
    VirtualHubRouteV2,
    VirtualNetwork,
    VirtualNetworkBgpCommunities,
    VirtualNetworkConnectionGatewayReference,
    VirtualNetworkDdosProtectionStatusResult,
    VirtualNetworkEncryption,
    VirtualNetworkGateway,
    VirtualNetworkGatewayAutoScaleBounds,
    VirtualNetworkGatewayAutoScaleConfiguration,
    VirtualNetworkGatewayConnection,
    VirtualNetworkGatewayConnectionListEntity,
    VirtualNetworkGatewayConnectionListResult,
    VirtualNetworkGatewayConnectionTunnelProperties,
    VirtualNetworkGatewayIPConfiguration,
    VirtualNetworkGatewayListConnectionsResult,
    VirtualNetworkGatewayListResult,
    VirtualNetworkGatewayMigrationParameters,
    VirtualNetworkGatewayMigrationStatus,
    VirtualNetworkGatewayNatRule,
    VirtualNetworkGatewayPolicyGroup,
    VirtualNetworkGatewayPolicyGroupMember,
    VirtualNetworkGatewaySku,
    VirtualNetworkListResult,
    VirtualNetworkListUsageResult,
    VirtualNetworkPeering,
    VirtualNetworkPeeringListResult,
    VirtualNetworkTap,
    VirtualNetworkTapListResult,
    VirtualNetworkUsage,
    VirtualNetworkUsageName,
    VirtualRouter,
    VirtualRouterAutoScaleConfiguration,
    VirtualRouterListResult,
    VirtualRouterPeering,
    VirtualRouterPeeringListResult,
    VirtualWAN,
    VirtualWanSecurityProvider,
    VirtualWanSecurityProviders,
    VirtualWanVpnProfileParameters,
    VnetRoute,
    VngClientConnectionConfiguration,
    VpnClientConfiguration,
    VpnClientConnectionHealth,
    VpnClientConnectionHealthDetail,
    VpnClientConnectionHealthDetailListResult,
    VpnClientIPsecParameters,
    VpnClientParameters,
    VpnClientRevokedCertificate,
    VpnClientRootCertificate,
    VpnConnection,
    VpnConnectionPacketCaptureStartParameters,
    VpnConnectionPacketCaptureStopParameters,
    VpnDeviceScriptParameters,
    VpnGateway,
    VpnGatewayIpConfiguration,
    VpnGatewayNatRule,
    VpnGatewayPacketCaptureStartParameters,
    VpnGatewayPacketCaptureStopParameters,
    VpnLinkBgpSettings,
    VpnLinkProviderProperties,
    VpnNatRuleMapping,
    VpnPacketCaptureStartParameters,
    VpnPacketCaptureStopParameters,
    VpnProfileResponse,
    VpnServerConfigRadiusClientRootCertificate,
    VpnServerConfigRadiusServerRootCertificate,
    VpnServerConfigVpnClientRevokedCertificate,
    VpnServerConfigVpnClientRootCertificate,
    VpnServerConfiguration,
    VpnServerConfigurationPolicyGroup,
    VpnServerConfigurationPolicyGroupMember,
    VpnServerConfigurationsResponse,
    VpnSite,
    VpnSiteId,
    VpnSiteLink,
    VpnSiteLinkConnection,
    WebApplicationFirewallCustomRule,
    WebApplicationFirewallPolicy,
    WebApplicationFirewallPolicyListResult,
    WebApplicationFirewallScrubbingRules,
)

from ._network_management_client_enums import (  # type: ignore
    Access,
    AccessRuleDirection,
    ActionType,
    AddressPrefixType,
    AddressSpaceAggregationOption,
    AdminRuleKind,
    AdminState,
    AdvertisedPublicPrefixPropertiesValidationState,
    ApplicationGatewayBackendHealthServerHealth,
    ApplicationGatewayClientRevocationOptions,
    ApplicationGatewayCookieBasedAffinity,
    ApplicationGatewayCustomErrorStatusCode,
    ApplicationGatewayFirewallMode,
    ApplicationGatewayFirewallRateLimitDuration,
    ApplicationGatewayFirewallUserSessionVariable,
    ApplicationGatewayLoadDistributionAlgorithm,
    ApplicationGatewayOperationalState,
    ApplicationGatewayProtocol,
    ApplicationGatewayRedirectType,
    ApplicationGatewayRequestRoutingRuleType,
    ApplicationGatewayRuleSetStatusOptions,
    ApplicationGatewaySkuFamily,
    ApplicationGatewaySkuName,
    ApplicationGatewaySslCipherSuite,
    ApplicationGatewaySslPolicyName,
    ApplicationGatewaySslPolicyType,
    ApplicationGatewaySslProtocol,
    ApplicationGatewayTier,
    ApplicationGatewayTierTypes,
    ApplicationGatewayWafRuleActionTypes,
    ApplicationGatewayWafRuleSensitivityTypes,
    ApplicationGatewayWafRuleStateTypes,
    AssociationAccessMode,
    AssociationType,
    AuthenticationMethod,
    AuthorizationUseStatus,
    AutoLearnPrivateRangesMode,
    AzureFirewallApplicationRuleProtocolType,
    AzureFirewallNatRCActionType,
    AzureFirewallNetworkRuleProtocol,
    AzureFirewallPacketCaptureFlagsType,
    AzureFirewallRCActionType,
    AzureFirewallSkuName,
    AzureFirewallSkuTier,
    AzureFirewallThreatIntelMode,
    BastionConnectProtocol,
    BastionHostSkuName,
    BgpPeerState,
    CircuitConnectionStatus,
    CommissionedState,
    ConfigurationType,
    ConnectedGroupAddressOverlap,
    ConnectedGroupPrivateEndpointsScale,
    ConnectionMonitorEndpointFilterItemType,
    ConnectionMonitorEndpointFilterType,
    ConnectionMonitorSourceStatus,
    ConnectionMonitorTestConfigurationProtocol,
    ConnectionMonitorType,
    ConnectionState,
    ConnectionStatus,
    ConnectivityTopology,
    CoverageLevel,
    CreatedByType,
    CustomIpPrefixType,
    DdosSettingsProtectionMode,
    DeleteExistingPeering,
    DeleteOptions,
    DeploymentStatus,
    DestinationPortBehavior,
    DhGroup,
    Direction,
    DisableBgpRoutePropagation,
    EffectiveAdminRuleKind,
    EffectiveRouteSource,
    EffectiveRouteState,
    EffectiveSecurityRuleProtocol,
    EndpointType,
    EvaluationState,
    ExceptionEntryMatchVariable,
    ExceptionEntrySelectorMatchOperator,
    ExceptionEntryValueMatchOperator,
    ExpressRouteCircuitPeeringAdvertisedPublicPrefixState,
    ExpressRouteCircuitPeeringState,
    ExpressRouteCircuitSkuFamily,
    ExpressRouteCircuitSkuTier,
    ExpressRouteLinkAdminState,
    ExpressRouteLinkConnectorType,
    ExpressRouteLinkMacSecCipher,
    ExpressRouteLinkMacSecSciState,
    ExpressRoutePeeringState,
    ExpressRoutePeeringType,
    ExpressRoutePortAuthorizationUseStatus,
    ExpressRoutePortsBillingType,
    ExpressRoutePortsEncapsulation,
    ExtendedLocationTypes,
    FailoverConnectionStatus,
    FailoverTestStatus,
    FailoverTestStatusForSingleTest,
    FailoverTestType,
    FirewallPolicyFilterRuleCollectionActionType,
    FirewallPolicyIDPSQuerySortOrder,
    FirewallPolicyIDPSSignatureDirection,
    FirewallPolicyIDPSSignatureMode,
    FirewallPolicyIDPSSignatureSeverity,
    FirewallPolicyIntrusionDetectionProfileType,
    FirewallPolicyIntrusionDetectionProtocol,
    FirewallPolicyIntrusionDetectionStateType,
    FirewallPolicyNatRuleCollectionActionType,
    FirewallPolicyRuleApplicationProtocolType,
    FirewallPolicyRuleCollectionType,
    FirewallPolicyRuleNetworkProtocol,
    FirewallPolicyRuleType,
    FirewallPolicySkuTier,
    FlowLogFormatType,
    GatewayLoadBalancerTunnelInterfaceType,
    GatewayLoadBalancerTunnelProtocol,
    Geo,
    GroupConnectivity,
    GroupMemberType,
    HTTPConfigurationMethod,
    HTTPMethod,
    HubBgpConnectionStatus,
    HubRoutingPreference,
    HubVirtualNetworkConnectionStatus,
    IPAllocationMethod,
    IPVersion,
    IkeEncryption,
    IkeIntegrity,
    InboundSecurityRuleType,
    InboundSecurityRulesProtocol,
    IpAllocationType,
    IpFlowProtocol,
    IpType,
    IpsecEncryption,
    IpsecIntegrity,
    IsGlobal,
    IsWorkloadProtected,
    IssueType,
    LoadBalancerBackendAddressAdminState,
    LoadBalancerOutboundRuleProtocol,
    LoadBalancerSkuName,
    LoadBalancerSkuTier,
    LoadDistribution,
    ManagedRuleEnabledState,
    NatGatewaySkuName,
    NetworkIntentPolicyBasedService,
    NetworkInterfaceAuxiliaryMode,
    NetworkInterfaceAuxiliarySku,
    NetworkInterfaceMigrationPhase,
    NetworkInterfaceNicType,
    NetworkOperationStatus,
    NetworkProtocol,
    NextHopType,
    NextStep,
    NicTypeInRequest,
    NicTypeInResponse,
    NspLinkProvisioningState,
    NspLinkStatus,
    NspProvisioningState,
    OfficeTrafficCategory,
    Origin,
    OutputType,
    OwaspCrsExclusionEntryMatchVariable,
    OwaspCrsExclusionEntrySelectorMatchOperator,
    PacketCaptureTargetType,
    PcError,
    PcProtocol,
    PcStatus,
    PeeringEnforcement,
    PfsGroup,
    PreferredIPVersion,
    PreferredRoutingGateway,
    PrivateEndpointVNetPolicies,
    ProbeNoHealthyBackendsBehavior,
    ProbeProtocol,
    ProcessorArchitecture,
    Protocol,
    ProtocolType,
    ProvisioningState,
    PublicIPAddressMigrationPhase,
    PublicIPAddressSkuName,
    PublicIPAddressSkuTier,
    PublicIPPrefixSkuName,
    PublicIPPrefixSkuTier,
    PublicIpAddressDnsSettingsDomainNameLabelScope,
    ResiliencyModel,
    ResourceIdentityType,
    RouteFilterRuleType,
    RouteMapActionType,
    RouteMapMatchCondition,
    RouteNextHopType,
    RoutingRuleDestinationType,
    RoutingRuleNextHopType,
    RoutingState,
    ScopeConnectionState,
    ScrubbingRuleEntryMatchOperator,
    ScrubbingRuleEntryMatchVariable,
    ScrubbingRuleEntryState,
    SecurityConfigurationRuleAccess,
    SecurityConfigurationRuleDirection,
    SecurityConfigurationRuleProtocol,
    SecurityPartnerProviderConnectionStatus,
    SecurityProviderName,
    SecurityRuleAccess,
    SecurityRuleDirection,
    SecurityRuleProtocol,
    SensitivityType,
    ServiceProviderProvisioningState,
    Severity,
    SharingScope,
    SlotType,
    SyncMode,
    SyncRemoteAddressSpace,
    TransportProtocol,
    TunnelConnectionStatus,
    UsageUnit,
    UseHubGateway,
    VerbosityLevel,
    VirtualNetworkEncryptionEnforcement,
    VirtualNetworkGatewayConnectionMode,
    VirtualNetworkGatewayConnectionProtocol,
    VirtualNetworkGatewayConnectionStatus,
    VirtualNetworkGatewayConnectionType,
    VirtualNetworkGatewayMigrationPhase,
    VirtualNetworkGatewayMigrationState,
    VirtualNetworkGatewayMigrationType,
    VirtualNetworkGatewaySkuName,
    VirtualNetworkGatewaySkuTier,
    VirtualNetworkGatewayType,
    VirtualNetworkPeeringLevel,
    VirtualNetworkPeeringState,
    VirtualNetworkPrivateEndpointNetworkPolicies,
    VirtualNetworkPrivateLinkServiceNetworkPolicies,
    VirtualWanSecurityProviderType,
    VnetLocalRouteOverrideCriteria,
    VpnAuthenticationType,
    VpnClientProtocol,
    VpnConnectionStatus,
    VpnGatewayGeneration,
    VpnGatewayTunnelingProtocol,
    VpnLinkConnectionMode,
    VpnNatRuleMode,
    VpnNatRuleType,
    VpnPolicyMemberAttributeType,
    VpnType,
    WebApplicationFirewallAction,
    WebApplicationFirewallEnabledState,
    WebApplicationFirewallMatchVariable,
    WebApplicationFirewallMode,
    WebApplicationFirewallOperator,
    WebApplicationFirewallPolicyResourceState,
    WebApplicationFirewallRuleType,
    WebApplicationFirewallScrubbingState,
    WebApplicationFirewallState,
    WebApplicationFirewallTransform,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AadAuthenticationParameters",
    "Action",
    "ActiveBaseSecurityAdminRule",
    "ActiveConfigurationParameter",
    "ActiveConnectivityConfiguration",
    "ActiveConnectivityConfigurationsListResult",
    "ActiveDefaultSecurityAdminRule",
    "ActiveSecurityAdminRule",
    "ActiveSecurityAdminRulesListResult",
    "AddressPrefixItem",
    "AddressSpace",
    "AdminRule",
    "AdminRuleCollection",
    "AdminRuleCollectionListResult",
    "AdminRuleListResult",
    "AdvertisedPublicPrefixProperties",
    "ApplicationGateway",
    "ApplicationGatewayAuthenticationCertificate",
    "ApplicationGatewayAutoscaleConfiguration",
    "ApplicationGatewayAvailableSslOptions",
    "ApplicationGatewayAvailableSslPredefinedPolicies",
    "ApplicationGatewayAvailableWafRuleSetsResult",
    "ApplicationGatewayBackendAddress",
    "ApplicationGatewayBackendAddressPool",
    "ApplicationGatewayBackendHealth",
    "ApplicationGatewayBackendHealthHttpSettings",
    "ApplicationGatewayBackendHealthOnDemand",
    "ApplicationGatewayBackendHealthPool",
    "ApplicationGatewayBackendHealthServer",
    "ApplicationGatewayBackendHttpSettings",
    "ApplicationGatewayBackendSettings",
    "ApplicationGatewayClientAuthConfiguration",
    "ApplicationGatewayConnectionDraining",
    "ApplicationGatewayCustomError",
    "ApplicationGatewayFirewallDisabledRuleGroup",
    "ApplicationGatewayFirewallExclusion",
    "ApplicationGatewayFirewallManifestRuleSet",
    "ApplicationGatewayFirewallRule",
    "ApplicationGatewayFirewallRuleGroup",
    "ApplicationGatewayFirewallRuleSet",
    "ApplicationGatewayForContainersReferenceDefinition",
    "ApplicationGatewayFrontendIPConfiguration",
    "ApplicationGatewayFrontendPort",
    "ApplicationGatewayGlobalConfiguration",
    "ApplicationGatewayHeaderConfiguration",
    "ApplicationGatewayHttpListener",
    "ApplicationGatewayIPConfiguration",
    "ApplicationGatewayListResult",
    "ApplicationGatewayListener",
    "ApplicationGatewayLoadDistributionPolicy",
    "ApplicationGatewayLoadDistributionTarget",
    "ApplicationGatewayOnDemandProbe",
    "ApplicationGatewayPathRule",
    "ApplicationGatewayPrivateEndpointConnection",
    "ApplicationGatewayPrivateEndpointConnectionListResult",
    "ApplicationGatewayPrivateLinkConfiguration",
    "ApplicationGatewayPrivateLinkIpConfiguration",
    "ApplicationGatewayPrivateLinkResource",
    "ApplicationGatewayPrivateLinkResourceListResult",
    "ApplicationGatewayProbe",
    "ApplicationGatewayProbeHealthResponseMatch",
    "ApplicationGatewayRedirectConfiguration",
    "ApplicationGatewayRequestRoutingRule",
    "ApplicationGatewayRewriteRule",
    "ApplicationGatewayRewriteRuleActionSet",
    "ApplicationGatewayRewriteRuleCondition",
    "ApplicationGatewayRewriteRuleSet",
    "ApplicationGatewayRoutingRule",
    "ApplicationGatewaySku",
    "ApplicationGatewaySslCertificate",
    "ApplicationGatewaySslPolicy",
    "ApplicationGatewaySslPredefinedPolicy",
    "ApplicationGatewaySslProfile",
    "ApplicationGatewayTrustedClientCertificate",
    "ApplicationGatewayTrustedRootCertificate",
    "ApplicationGatewayUrlConfiguration",
    "ApplicationGatewayUrlPathMap",
    "ApplicationGatewayWafDynamicManifestResult",
    "ApplicationGatewayWafDynamicManifestResultList",
    "ApplicationGatewayWebApplicationFirewallConfiguration",
    "ApplicationRule",
    "ApplicationSecurityGroup",
    "ApplicationSecurityGroupListResult",
    "AuthorizationListResult",
    "AutoApprovedPrivateLinkService",
    "AutoApprovedPrivateLinkServicesResult",
    "Availability",
    "AvailableDelegation",
    "AvailableDelegationsResult",
    "AvailablePrivateEndpointType",
    "AvailablePrivateEndpointTypesResult",
    "AvailableProvidersList",
    "AvailableProvidersListCity",
    "AvailableProvidersListCountry",
    "AvailableProvidersListParameters",
    "AvailableProvidersListState",
    "AvailableServiceAlias",
    "AvailableServiceAliasesResult",
    "AzureAsyncOperationResult",
    "AzureFirewall",
    "AzureFirewallApplicationRule",
    "AzureFirewallApplicationRuleCollection",
    "AzureFirewallApplicationRuleProtocol",
    "AzureFirewallAutoscaleConfiguration",
    "AzureFirewallFqdnTag",
    "AzureFirewallFqdnTagListResult",
    "AzureFirewallIPConfiguration",
    "AzureFirewallIpGroups",
    "AzureFirewallListResult",
    "AzureFirewallNatRCAction",
    "AzureFirewallNatRule",
    "AzureFirewallNatRuleCollection",
    "AzureFirewallNetworkRule",
    "AzureFirewallNetworkRuleCollection",
    "AzureFirewallPacketCaptureFlags",
    "AzureFirewallPacketCaptureRule",
    "AzureFirewallPublicIPAddress",
    "AzureFirewallRCAction",
    "AzureFirewallSku",
    "AzureReachabilityReport",
    "AzureReachabilityReportItem",
    "AzureReachabilityReportLatencyInfo",
    "AzureReachabilityReportLocation",
    "AzureReachabilityReportParameters",
    "AzureWebCategory",
    "AzureWebCategoryListResult",
    "BGPCommunity",
    "BackendAddressInboundNatRulePortMappings",
    "BackendAddressPool",
    "BaseAdminRule",
    "BastionActiveSession",
    "BastionActiveSessionListResult",
    "BastionHost",
    "BastionHostIPConfiguration",
    "BastionHostListResult",
    "BastionHostPropertiesFormatNetworkAcls",
    "BastionSessionDeleteResult",
    "BastionSessionState",
    "BastionShareableLink",
    "BastionShareableLinkListRequest",
    "BastionShareableLinkListResult",
    "BastionShareableLinkTokenListRequest",
    "BgpConnection",
    "BgpPeerStatus",
    "BgpPeerStatusListResult",
    "BgpServiceCommunity",
    "BgpServiceCommunityListResult",
    "BgpSettings",
    "BreakOutCategoryPolicies",
    "CheckPrivateLinkServiceVisibilityRequest",
    "ChildResource",
    "CircuitMetadataMap",
    "CloudErrorBody",
    "CommonErrorAdditionalInfo",
    "CommonErrorDetail",
    "CommonErrorResponse",
    "CommonProxyResource",
    "CommonResource",
    "CommonTrackedResource",
    "Components1Jq1T4ISchemasManagedserviceidentityPropertiesUserassignedidentitiesAdditionalproperties",
    "ConfigurationGroup",
    "ConnectionMonitor",
    "ConnectionMonitorDestination",
    "ConnectionMonitorEndpoint",
    "ConnectionMonitorEndpointFilter",
    "ConnectionMonitorEndpointFilterItem",
    "ConnectionMonitorEndpointLocationDetails",
    "ConnectionMonitorEndpointScope",
    "ConnectionMonitorEndpointScopeItem",
    "ConnectionMonitorHttpConfiguration",
    "ConnectionMonitorIcmpConfiguration",
    "ConnectionMonitorListResult",
    "ConnectionMonitorOutput",
    "ConnectionMonitorParameters",
    "ConnectionMonitorQueryResult",
    "ConnectionMonitorResult",
    "ConnectionMonitorResultProperties",
    "ConnectionMonitorSource",
    "ConnectionMonitorSuccessThreshold",
    "ConnectionMonitorTcpConfiguration",
    "ConnectionMonitorTestConfiguration",
    "ConnectionMonitorTestGroup",
    "ConnectionMonitorWorkspaceSettings",
    "ConnectionResetSharedKey",
    "ConnectionSharedKey",
    "ConnectionSharedKeyResult",
    "ConnectionSharedKeyResultList",
    "ConnectionStateSnapshot",
    "ConnectivityConfiguration",
    "ConnectivityConfigurationListResult",
    "ConnectivityConfigurationPropertiesConnectivityCapabilities",
    "ConnectivityDestination",
    "ConnectivityGroupItem",
    "ConnectivityHop",
    "ConnectivityInformation",
    "ConnectivityIssue",
    "ConnectivityParameters",
    "ConnectivitySource",
    "Container",
    "ContainerNetworkInterface",
    "ContainerNetworkInterfaceConfiguration",
    "ContainerNetworkInterfaceIpConfiguration",
    "Criterion",
    "CrossTenantScopes",
    "CustomDnsConfigPropertiesFormat",
    "CustomIpPrefix",
    "CustomIpPrefixListResult",
    "DdosCustomPolicy",
    "DdosProtectionPlan",
    "DdosProtectionPlanListResult",
    "DdosSettings",
    "DefaultAdminRule",
    "Delegation",
    "DelegationProperties",
    "DeviceProperties",
    "DhcpOptions",
    "Dimension",
    "DnsNameAvailabilityResult",
    "DnsSettings",
    "DscpConfiguration",
    "DscpConfigurationListResult",
    "EffectiveBaseSecurityAdminRule",
    "EffectiveConnectivityConfiguration",
    "EffectiveDefaultSecurityAdminRule",
    "EffectiveNetworkSecurityGroup",
    "EffectiveNetworkSecurityGroupAssociation",
    "EffectiveNetworkSecurityGroupListResult",
    "EffectiveNetworkSecurityRule",
    "EffectiveRoute",
    "EffectiveRouteListResult",
    "EffectiveRouteMapRoute",
    "EffectiveRouteMapRouteList",
    "EffectiveRoutesParameters",
    "EffectiveSecurityAdminRule",
    "EndpointServiceResult",
    "EndpointServicesListResult",
    "Error",
    "ErrorAdditionalInfo",
    "ErrorDetail",
    "ErrorDetails",
    "ErrorResponse",
    "EvaluatedNetworkSecurityGroup",
    "ExceptionEntry",
    "ExclusionManagedRule",
    "ExclusionManagedRuleGroup",
    "ExclusionManagedRuleSet",
    "ExplicitProxy",
    "ExpressRouteCircuit",
    "ExpressRouteCircuitArpTable",
    "ExpressRouteCircuitAuthorization",
    "ExpressRouteCircuitConnection",
    "ExpressRouteCircuitConnectionListResult",
    "ExpressRouteCircuitListResult",
    "ExpressRouteCircuitPeering",
    "ExpressRouteCircuitPeeringConfig",
    "ExpressRouteCircuitPeeringId",
    "ExpressRouteCircuitPeeringListResult",
    "ExpressRouteCircuitReference",
    "ExpressRouteCircuitRoutesTable",
    "ExpressRouteCircuitRoutesTableSummary",
    "ExpressRouteCircuitServiceProviderProperties",
    "ExpressRouteCircuitSku",
    "ExpressRouteCircuitStats",
    "ExpressRouteCircuitsArpTableListResult",
    "ExpressRouteCircuitsRoutesTableListResult",
    "ExpressRouteCircuitsRoutesTableSummaryListResult",
    "ExpressRouteConnection",
    "ExpressRouteConnectionId",
    "ExpressRouteConnectionList",
    "ExpressRouteCrossConnection",
    "ExpressRouteCrossConnectionListResult",
    "ExpressRouteCrossConnectionPeering",
    "ExpressRouteCrossConnectionPeeringList",
    "ExpressRouteCrossConnectionRoutesTableSummary",
    "ExpressRouteCrossConnectionsRoutesTableSummaryListResult",
    "ExpressRouteFailoverCircuitResourceDetails",
    "ExpressRouteFailoverConnectionResourceDetails",
    "ExpressRouteFailoverRedundantRoute",
    "ExpressRouteFailoverSingleTestDetails",
    "ExpressRouteFailoverStopApiParameters",
    "ExpressRouteFailoverTestDetails",
    "ExpressRouteGateway",
    "ExpressRouteGatewayList",
    "ExpressRouteGatewayPropertiesAutoScaleConfiguration",
    "ExpressRouteGatewayPropertiesAutoScaleConfigurationBounds",
    "ExpressRouteLink",
    "ExpressRouteLinkListResult",
    "ExpressRouteLinkMacSecConfig",
    "ExpressRoutePort",
    "ExpressRoutePortAuthorization",
    "ExpressRoutePortAuthorizationListResult",
    "ExpressRoutePortListResult",
    "ExpressRoutePortsLocation",
    "ExpressRoutePortsLocationBandwidths",
    "ExpressRoutePortsLocationListResult",
    "ExpressRouteProviderPort",
    "ExpressRouteProviderPortListResult",
    "ExpressRouteServiceProvider",
    "ExpressRouteServiceProviderBandwidthsOffered",
    "ExpressRouteServiceProviderListResult",
    "ExtendedLocation",
    "FailoverConnectionDetails",
    "FilterItems",
    "FirewallPacketCaptureParameters",
    "FirewallPolicy",
    "FirewallPolicyCertificateAuthority",
    "FirewallPolicyDraft",
    "FirewallPolicyFilterRuleCollection",
    "FirewallPolicyFilterRuleCollectionAction",
    "FirewallPolicyHttpHeaderToInsert",
    "FirewallPolicyInsights",
    "FirewallPolicyIntrusionDetection",
    "FirewallPolicyIntrusionDetectionBypassTrafficSpecifications",
    "FirewallPolicyIntrusionDetectionConfiguration",
    "FirewallPolicyIntrusionDetectionSignatureSpecification",
    "FirewallPolicyListResult",
    "FirewallPolicyLogAnalyticsResources",
    "FirewallPolicyLogAnalyticsWorkspace",
    "FirewallPolicyNatRuleCollection",
    "FirewallPolicyNatRuleCollectionAction",
    "FirewallPolicyRule",
    "FirewallPolicyRuleApplicationProtocol",
    "FirewallPolicyRuleCollection",
    "FirewallPolicyRuleCollectionGroup",
    "FirewallPolicyRuleCollectionGroupDraft",
    "FirewallPolicyRuleCollectionGroupListResult",
    "FirewallPolicySNAT",
    "FirewallPolicySQL",
    "FirewallPolicySku",
    "FirewallPolicyThreatIntelWhitelist",
    "FirewallPolicyTransportSecurity",
    "FlowLog",
    "FlowLogFormatParameters",
    "FlowLogInformation",
    "FlowLogListResult",
    "FlowLogStatusParameters",
    "FrontendIPConfiguration",
    "GatewayCustomBgpIpAddressIpConfiguration",
    "GatewayLoadBalancerTunnelInterface",
    "GatewayResiliencyInformation",
    "GatewayResiliencyRecommendation",
    "GatewayRoute",
    "GatewayRouteListResult",
    "GatewayRouteSet",
    "GatewayRouteSetsInformation",
    "GenerateExpressRoutePortsLOARequest",
    "GenerateExpressRoutePortsLOAResult",
    "GetInboundRoutesParameters",
    "GetOutboundRoutesParameters",
    "GetVpnSitesConfigurationRequest",
    "GroupByUserSession",
    "GroupByVariable",
    "HTTPConfiguration",
    "HTTPHeader",
    "HeaderValueMatcher",
    "HopLink",
    "Hub",
    "HubIPAddresses",
    "HubIpConfiguration",
    "HubPublicIPAddresses",
    "HubRoute",
    "HubRouteTable",
    "HubVirtualNetworkConnection",
    "IDPSQueryObject",
    "IPAddressAvailabilityResult",
    "IPConfiguration",
    "IPConfigurationBgpPeeringAddress",
    "IPConfigurationProfile",
    "IPPrefixesList",
    "IPRule",
    "IPTraffic",
    "InboundNatPool",
    "InboundNatRule",
    "InboundNatRuleListResult",
    "InboundNatRulePortMapping",
    "InboundSecurityRule",
    "InboundSecurityRules",
    "IntentContent",
    "InternetIngressPublicIpsProperties",
    "IpAllocation",
    "IpAllocationListResult",
    "IpGroup",
    "IpGroupListResult",
    "IpTag",
    "IpamPool",
    "IpamPoolList",
    "IpamPoolPrefixAllocation",
    "IpamPoolProperties",
    "IpamPoolUpdate",
    "IpamPoolUpdateProperties",
    "IpsecPolicy",
    "Ipv6CircuitConnectionConfig",
    "Ipv6ExpressRouteCircuitPeeringConfig",
    "ListHubRouteTablesResult",
    "ListHubVirtualNetworkConnectionsResult",
    "ListP2SVpnGatewaysResult",
    "ListRouteMapsResult",
    "ListRoutingIntentResult",
    "ListVirtualHubBgpConnectionResults",
    "ListVirtualHubIpConfigurationResults",
    "ListVirtualHubRouteTableV2SResult",
    "ListVirtualHubsResult",
    "ListVirtualNetworkGatewayNatRulesResult",
    "ListVirtualWANsResult",
    "ListVpnConnectionsResult",
    "ListVpnGatewayNatRulesResult",
    "ListVpnGatewaysResult",
    "ListVpnServerConfigurationPolicyGroupsResult",
    "ListVpnServerConfigurationsResult",
    "ListVpnSiteLinkConnectionsResult",
    "ListVpnSiteLinksResult",
    "ListVpnSitesResult",
    "LoadBalancer",
    "LoadBalancerBackendAddress",
    "LoadBalancerBackendAddressPoolListResult",
    "LoadBalancerFrontendIPConfigurationListResult",
    "LoadBalancerHealthPerRule",
    "LoadBalancerHealthPerRulePerBackendAddress",
    "LoadBalancerListResult",
    "LoadBalancerLoadBalancingRuleListResult",
    "LoadBalancerOutboundRuleListResult",
    "LoadBalancerProbeListResult",
    "LoadBalancerSku",
    "LoadBalancerVipSwapRequest",
    "LoadBalancerVipSwapRequestFrontendIPConfiguration",
    "LoadBalancingRule",
    "LocalNetworkGateway",
    "LocalNetworkGatewayListResult",
    "LogSpecification",
    "ManagedRuleGroupOverride",
    "ManagedRuleOverride",
    "ManagedRuleSet",
    "ManagedRuleSetRuleGroup",
    "ManagedRulesDefinition",
    "ManagedServiceIdentity",
    "MatchCondition",
    "MatchVariable",
    "MatchedRule",
    "MetricSpecification",
    "MigrateLoadBalancerToIpBasedRequest",
    "MigratedPools",
    "NatGateway",
    "NatGatewayListResult",
    "NatGatewaySku",
    "NatRule",
    "NatRulePortMapping",
    "NetworkConfigurationDiagnosticParameters",
    "NetworkConfigurationDiagnosticProfile",
    "NetworkConfigurationDiagnosticResponse",
    "NetworkConfigurationDiagnosticResult",
    "NetworkGroup",
    "NetworkGroupListResult",
    "NetworkIntentPolicy",
    "NetworkIntentPolicyConfiguration",
    "NetworkInterface",
    "NetworkInterfaceAssociation",
    "NetworkInterfaceDnsSettings",
    "NetworkInterfaceIPConfiguration",
    "NetworkInterfaceIPConfigurationListResult",
    "NetworkInterfaceIPConfigurationPrivateLinkConnectionProperties",
    "NetworkInterfaceListResult",
    "NetworkInterfaceLoadBalancerListResult",
    "NetworkInterfaceTapConfiguration",
    "NetworkInterfaceTapConfigurationListResult",
    "NetworkManager",
    "NetworkManagerCommit",
    "NetworkManagerConnection",
    "NetworkManagerConnectionListResult",
    "NetworkManagerDeploymentStatus",
    "NetworkManagerDeploymentStatusListResult",
    "NetworkManagerDeploymentStatusParameter",
    "NetworkManagerEffectiveConnectivityConfigurationListResult",
    "NetworkManagerEffectiveSecurityAdminRulesListResult",
    "NetworkManagerListResult",
    "NetworkManagerPropertiesNetworkManagerScopes",
    "NetworkManagerRoutingConfiguration",
    "NetworkManagerRoutingConfigurationListResult",
    "NetworkManagerRoutingGroupItem",
    "NetworkManagerSecurityGroupItem",
    "NetworkProfile",
    "NetworkProfileListResult",
    "NetworkRule",
    "NetworkSecurityGroup",
    "NetworkSecurityGroupListResult",
    "NetworkSecurityGroupResult",
    "NetworkSecurityPerimeter",
    "NetworkSecurityPerimeterListResult",
    "NetworkSecurityRulesEvaluationResult",
    "NetworkVirtualAppliance",
    "NetworkVirtualApplianceBootDiagnosticParameters",
    "NetworkVirtualApplianceConnection",
    "NetworkVirtualApplianceConnectionList",
    "NetworkVirtualApplianceInstanceId",
    "NetworkVirtualApplianceInstanceIds",
    "NetworkVirtualApplianceListResult",
    "NetworkVirtualAppliancePropertiesFormatNetworkProfile",
    "NetworkVirtualApplianceSiteListResult",
    "NetworkVirtualApplianceSku",
    "NetworkVirtualApplianceSkuInstances",
    "NetworkVirtualApplianceSkuListResult",
    "NetworkWatcher",
    "NetworkWatcherListResult",
    "NextHopParameters",
    "NextHopResult",
    "NspAccessRule",
    "NspAccessRuleListResult",
    "NspAssociation",
    "NspAssociationsListResult",
    "NspLink",
    "NspLinkListResult",
    "NspLinkReference",
    "NspLinkReferenceListResult",
    "NspLoggingConfiguration",
    "NspLoggingConfigurationListResult",
    "NspProfile",
    "NspProfileListResult",
    "O365BreakOutCategoryPolicies",
    "O365PolicyProperties",
    "Office365PolicyProperties",
    "Operation",
    "OperationDisplay",
    "OperationListResult",
    "OperationPropertiesFormatServiceSpecification",
    "OperationStatusResult",
    "OrderBy",
    "OutboundRule",
    "OwaspCrsExclusionEntry",
    "P2SConnectionConfiguration",
    "P2SVpnConnectionHealth",
    "P2SVpnConnectionHealthRequest",
    "P2SVpnConnectionRequest",
    "P2SVpnGateway",
    "P2SVpnProfileParameters",
    "PacketCapture",
    "PacketCaptureFilter",
    "PacketCaptureListResult",
    "PacketCaptureMachineScope",
    "PacketCaptureParameters",
    "PacketCaptureQueryStatusResult",
    "PacketCaptureResult",
    "PacketCaptureResultProperties",
    "PacketCaptureSettings",
    "PacketCaptureStorageLocation",
    "Parameter",
    "PartnerManagedResourceProperties",
    "PatchObject",
    "PatchRouteFilter",
    "PatchRouteFilterRule",
    "PeerExpressRouteCircuitConnection",
    "PeerExpressRouteCircuitConnectionListResult",
    "PeerRoute",
    "PerimeterAssociableResource",
    "PerimeterAssociableResourcesListResult",
    "PerimeterBasedAccessRule",
    "PolicySettings",
    "PolicySettingsLogScrubbing",
    "PoolAssociation",
    "PoolAssociationList",
    "PoolUsage",
    "PrepareNetworkPoliciesRequest",
    "PrivateDnsZoneConfig",
    "PrivateDnsZoneGroup",
    "PrivateDnsZoneGroupListResult",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionListResult",
    "PrivateEndpointIPConfiguration",
    "PrivateEndpointListResult",
    "PrivateLinkService",
    "PrivateLinkServiceConnection",
    "PrivateLinkServiceConnectionState",
    "PrivateLinkServiceIpConfiguration",
    "PrivateLinkServiceListResult",
    "PrivateLinkServicePropertiesAutoApproval",
    "PrivateLinkServicePropertiesVisibility",
    "PrivateLinkServiceVisibility",
    "Probe",
    "PropagatedRouteTable",
    "ProtocolConfiguration",
    "ProxyResource",
    "PublicIPAddress",
    "PublicIPAddressDnsSettings",
    "PublicIPAddressListResult",
    "PublicIPAddressSku",
    "PublicIPPrefix",
    "PublicIPPrefixListResult",
    "PublicIPPrefixSku",
    "PublicIpDdosProtectionStatusResult",
    "QosDefinition",
    "QosIpRange",
    "QosPortRange",
    "QueryInboundNatRulePortMappingRequest",
    "QueryRequestOptions",
    "QueryResults",
    "QueryTroubleshootingParameters",
    "RadiusServer",
    "ReachabilityAnalysisIntent",
    "ReachabilityAnalysisIntentListResult",
    "ReachabilityAnalysisIntentProperties",
    "ReachabilityAnalysisRun",
    "ReachabilityAnalysisRunListResult",
    "ReachabilityAnalysisRunProperties",
    "RecordSet",
    "ReferencedPublicIpAddress",
    "ResiliencyRecommendationComponents",
    "Resource",
    "ResourceBasics",
    "ResourceNavigationLink",
    "ResourceNavigationLinksListResult",
    "ResourceSet",
    "RetentionPolicyParameters",
    "Route",
    "RouteFilter",
    "RouteFilterListResult",
    "RouteFilterRule",
    "RouteFilterRuleListResult",
    "RouteListResult",
    "RouteMap",
    "RouteMapRule",
    "RouteSourceDetails",
    "RouteTable",
    "RouteTableListResult",
    "RoutingConfiguration",
    "RoutingIntent",
    "RoutingPolicy",
    "RoutingRule",
    "RoutingRuleCollection",
    "RoutingRuleCollectionListResult",
    "RoutingRuleListResult",
    "RoutingRuleNextHop",
    "RoutingRuleRouteDestination",
    "ScopeConnection",
    "ScopeConnectionListResult",
    "SecurityAdminConfiguration",
    "SecurityAdminConfigurationListResult",
    "SecurityGroupNetworkInterface",
    "SecurityGroupViewParameters",
    "SecurityGroupViewResult",
    "SecurityPartnerProvider",
    "SecurityPartnerProviderListResult",
    "SecurityPerimeterProxyResource",
    "SecurityPerimeterResource",
    "SecurityPerimeterSystemData",
    "SecurityRule",
    "SecurityRuleAssociations",
    "SecurityRuleListResult",
    "SecurityUserConfiguration",
    "SecurityUserConfigurationListResult",
    "SecurityUserGroupItem",
    "SecurityUserRule",
    "SecurityUserRuleCollection",
    "SecurityUserRuleCollectionListResult",
    "SecurityUserRuleListResult",
    "ServiceAssociationLink",
    "ServiceAssociationLinksListResult",
    "ServiceEndpointPolicy",
    "ServiceEndpointPolicyDefinition",
    "ServiceEndpointPolicyDefinitionListResult",
    "ServiceEndpointPolicyListResult",
    "ServiceEndpointPropertiesFormat",
    "ServiceTagInformation",
    "ServiceTagInformationListResult",
    "ServiceTagInformationPropertiesFormat",
    "ServiceTagsListResult",
    "SessionIds",
    "SharedKeyProperties",
    "SignatureOverridesFilterValuesQuery",
    "SignatureOverridesFilterValuesResponse",
    "SignaturesOverrides",
    "SignaturesOverridesList",
    "SignaturesOverridesProperties",
    "SingleQueryResult",
    "Sku",
    "StaticCidr",
    "StaticCidrList",
    "StaticCidrProperties",
    "StaticMember",
    "StaticMemberListResult",
    "StaticRoute",
    "StaticRoutesConfig",
    "SubResource",
    "Subnet",
    "SubnetAssociation",
    "SubnetListResult",
    "SubscriptionId",
    "SwapResource",
    "SwapResourceListResult",
    "SwapResourceProperties",
    "SystemData",
    "TagsObject",
    "Topology",
    "TopologyAssociation",
    "TopologyParameters",
    "TopologyResource",
    "TrackedResource",
    "TrafficAnalyticsConfigurationProperties",
    "TrafficAnalyticsProperties",
    "TrafficSelectorPolicy",
    "TroubleshootingDetails",
    "TroubleshootingParameters",
    "TroubleshootingRecommendedActions",
    "TroubleshootingResult",
    "TunnelConnectionHealth",
    "UnprepareNetworkPoliciesRequest",
    "UpdateTagsRequest",
    "Usage",
    "UsageName",
    "UsagesListResult",
    "VM",
    "VerificationIPFlowParameters",
    "VerificationIPFlowResult",
    "VerifierWorkspace",
    "VerifierWorkspaceListResult",
    "VerifierWorkspaceProperties",
    "VerifierWorkspaceUpdate",
    "VerifierWorkspaceUpdateProperties",
    "VirtualApplianceAdditionalNicProperties",
    "VirtualApplianceIPConfiguration",
    "VirtualApplianceIPConfigurationProperties",
    "VirtualApplianceNetworkInterfaceConfiguration",
    "VirtualApplianceNetworkInterfaceConfigurationProperties",
    "VirtualApplianceNicProperties",
    "VirtualApplianceSite",
    "VirtualApplianceSkuProperties",
    "VirtualHub",
    "VirtualHubEffectiveRoute",
    "VirtualHubEffectiveRouteList",
    "VirtualHubId",
    "VirtualHubRoute",
    "VirtualHubRouteTable",
    "VirtualHubRouteTableV2",
    "VirtualHubRouteV2",
    "VirtualNetwork",
    "VirtualNetworkBgpCommunities",
    "VirtualNetworkConnectionGatewayReference",
    "VirtualNetworkDdosProtectionStatusResult",
    "VirtualNetworkEncryption",
    "VirtualNetworkGateway",
    "VirtualNetworkGatewayAutoScaleBounds",
    "VirtualNetworkGatewayAutoScaleConfiguration",
    "VirtualNetworkGatewayConnection",
    "VirtualNetworkGatewayConnectionListEntity",
    "VirtualNetworkGatewayConnectionListResult",
    "VirtualNetworkGatewayConnectionTunnelProperties",
    "VirtualNetworkGatewayIPConfiguration",
    "VirtualNetworkGatewayListConnectionsResult",
    "VirtualNetworkGatewayListResult",
    "VirtualNetworkGatewayMigrationParameters",
    "VirtualNetworkGatewayMigrationStatus",
    "VirtualNetworkGatewayNatRule",
    "VirtualNetworkGatewayPolicyGroup",
    "VirtualNetworkGatewayPolicyGroupMember",
    "VirtualNetworkGatewaySku",
    "VirtualNetworkListResult",
    "VirtualNetworkListUsageResult",
    "VirtualNetworkPeering",
    "VirtualNetworkPeeringListResult",
    "VirtualNetworkTap",
    "VirtualNetworkTapListResult",
    "VirtualNetworkUsage",
    "VirtualNetworkUsageName",
    "VirtualRouter",
    "VirtualRouterAutoScaleConfiguration",
    "VirtualRouterListResult",
    "VirtualRouterPeering",
    "VirtualRouterPeeringListResult",
    "VirtualWAN",
    "VirtualWanSecurityProvider",
    "VirtualWanSecurityProviders",
    "VirtualWanVpnProfileParameters",
    "VnetRoute",
    "VngClientConnectionConfiguration",
    "VpnClientConfiguration",
    "VpnClientConnectionHealth",
    "VpnClientConnectionHealthDetail",
    "VpnClientConnectionHealthDetailListResult",
    "VpnClientIPsecParameters",
    "VpnClientParameters",
    "VpnClientRevokedCertificate",
    "VpnClientRootCertificate",
    "VpnConnection",
    "VpnConnectionPacketCaptureStartParameters",
    "VpnConnectionPacketCaptureStopParameters",
    "VpnDeviceScriptParameters",
    "VpnGateway",
    "VpnGatewayIpConfiguration",
    "VpnGatewayNatRule",
    "VpnGatewayPacketCaptureStartParameters",
    "VpnGatewayPacketCaptureStopParameters",
    "VpnLinkBgpSettings",
    "VpnLinkProviderProperties",
    "VpnNatRuleMapping",
    "VpnPacketCaptureStartParameters",
    "VpnPacketCaptureStopParameters",
    "VpnProfileResponse",
    "VpnServerConfigRadiusClientRootCertificate",
    "VpnServerConfigRadiusServerRootCertificate",
    "VpnServerConfigVpnClientRevokedCertificate",
    "VpnServerConfigVpnClientRootCertificate",
    "VpnServerConfiguration",
    "VpnServerConfigurationPolicyGroup",
    "VpnServerConfigurationPolicyGroupMember",
    "VpnServerConfigurationsResponse",
    "VpnSite",
    "VpnSiteId",
    "VpnSiteLink",
    "VpnSiteLinkConnection",
    "WebApplicationFirewallCustomRule",
    "WebApplicationFirewallPolicy",
    "WebApplicationFirewallPolicyListResult",
    "WebApplicationFirewallScrubbingRules",
    "Access",
    "AccessRuleDirection",
    "ActionType",
    "AddressPrefixType",
    "AddressSpaceAggregationOption",
    "AdminRuleKind",
    "AdminState",
    "AdvertisedPublicPrefixPropertiesValidationState",
    "ApplicationGatewayBackendHealthServerHealth",
    "ApplicationGatewayClientRevocationOptions",
    "ApplicationGatewayCookieBasedAffinity",
    "ApplicationGatewayCustomErrorStatusCode",
    "ApplicationGatewayFirewallMode",
    "ApplicationGatewayFirewallRateLimitDuration",
    "ApplicationGatewayFirewallUserSessionVariable",
    "ApplicationGatewayLoadDistributionAlgorithm",
    "ApplicationGatewayOperationalState",
    "ApplicationGatewayProtocol",
    "ApplicationGatewayRedirectType",
    "ApplicationGatewayRequestRoutingRuleType",
    "ApplicationGatewayRuleSetStatusOptions",
    "ApplicationGatewaySkuFamily",
    "ApplicationGatewaySkuName",
    "ApplicationGatewaySslCipherSuite",
    "ApplicationGatewaySslPolicyName",
    "ApplicationGatewaySslPolicyType",
    "ApplicationGatewaySslProtocol",
    "ApplicationGatewayTier",
    "ApplicationGatewayTierTypes",
    "ApplicationGatewayWafRuleActionTypes",
    "ApplicationGatewayWafRuleSensitivityTypes",
    "ApplicationGatewayWafRuleStateTypes",
    "AssociationAccessMode",
    "AssociationType",
    "AuthenticationMethod",
    "AuthorizationUseStatus",
    "AutoLearnPrivateRangesMode",
    "AzureFirewallApplicationRuleProtocolType",
    "AzureFirewallNatRCActionType",
    "AzureFirewallNetworkRuleProtocol",
    "AzureFirewallPacketCaptureFlagsType",
    "AzureFirewallRCActionType",
    "AzureFirewallSkuName",
    "AzureFirewallSkuTier",
    "AzureFirewallThreatIntelMode",
    "BastionConnectProtocol",
    "BastionHostSkuName",
    "BgpPeerState",
    "CircuitConnectionStatus",
    "CommissionedState",
    "ConfigurationType",
    "ConnectedGroupAddressOverlap",
    "ConnectedGroupPrivateEndpointsScale",
    "ConnectionMonitorEndpointFilterItemType",
    "ConnectionMonitorEndpointFilterType",
    "ConnectionMonitorSourceStatus",
    "ConnectionMonitorTestConfigurationProtocol",
    "ConnectionMonitorType",
    "ConnectionState",
    "ConnectionStatus",
    "ConnectivityTopology",
    "CoverageLevel",
    "CreatedByType",
    "CustomIpPrefixType",
    "DdosSettingsProtectionMode",
    "DeleteExistingPeering",
    "DeleteOptions",
    "DeploymentStatus",
    "DestinationPortBehavior",
    "DhGroup",
    "Direction",
    "DisableBgpRoutePropagation",
    "EffectiveAdminRuleKind",
    "EffectiveRouteSource",
    "EffectiveRouteState",
    "EffectiveSecurityRuleProtocol",
    "EndpointType",
    "EvaluationState",
    "ExceptionEntryMatchVariable",
    "ExceptionEntrySelectorMatchOperator",
    "ExceptionEntryValueMatchOperator",
    "ExpressRouteCircuitPeeringAdvertisedPublicPrefixState",
    "ExpressRouteCircuitPeeringState",
    "ExpressRouteCircuitSkuFamily",
    "ExpressRouteCircuitSkuTier",
    "ExpressRouteLinkAdminState",
    "ExpressRouteLinkConnectorType",
    "ExpressRouteLinkMacSecCipher",
    "ExpressRouteLinkMacSecSciState",
    "ExpressRoutePeeringState",
    "ExpressRoutePeeringType",
    "ExpressRoutePortAuthorizationUseStatus",
    "ExpressRoutePortsBillingType",
    "ExpressRoutePortsEncapsulation",
    "ExtendedLocationTypes",
    "FailoverConnectionStatus",
    "FailoverTestStatus",
    "FailoverTestStatusForSingleTest",
    "FailoverTestType",
    "FirewallPolicyFilterRuleCollectionActionType",
    "FirewallPolicyIDPSQuerySortOrder",
    "FirewallPolicyIDPSSignatureDirection",
    "FirewallPolicyIDPSSignatureMode",
    "FirewallPolicyIDPSSignatureSeverity",
    "FirewallPolicyIntrusionDetectionProfileType",
    "FirewallPolicyIntrusionDetectionProtocol",
    "FirewallPolicyIntrusionDetectionStateType",
    "FirewallPolicyNatRuleCollectionActionType",
    "FirewallPolicyRuleApplicationProtocolType",
    "FirewallPolicyRuleCollectionType",
    "FirewallPolicyRuleNetworkProtocol",
    "FirewallPolicyRuleType",
    "FirewallPolicySkuTier",
    "FlowLogFormatType",
    "GatewayLoadBalancerTunnelInterfaceType",
    "GatewayLoadBalancerTunnelProtocol",
    "Geo",
    "GroupConnectivity",
    "GroupMemberType",
    "HTTPConfigurationMethod",
    "HTTPMethod",
    "HubBgpConnectionStatus",
    "HubRoutingPreference",
    "HubVirtualNetworkConnectionStatus",
    "IPAllocationMethod",
    "IPVersion",
    "IkeEncryption",
    "IkeIntegrity",
    "InboundSecurityRuleType",
    "InboundSecurityRulesProtocol",
    "IpAllocationType",
    "IpFlowProtocol",
    "IpType",
    "IpsecEncryption",
    "IpsecIntegrity",
    "IsGlobal",
    "IsWorkloadProtected",
    "IssueType",
    "LoadBalancerBackendAddressAdminState",
    "LoadBalancerOutboundRuleProtocol",
    "LoadBalancerSkuName",
    "LoadBalancerSkuTier",
    "LoadDistribution",
    "ManagedRuleEnabledState",
    "NatGatewaySkuName",
    "NetworkIntentPolicyBasedService",
    "NetworkInterfaceAuxiliaryMode",
    "NetworkInterfaceAuxiliarySku",
    "NetworkInterfaceMigrationPhase",
    "NetworkInterfaceNicType",
    "NetworkOperationStatus",
    "NetworkProtocol",
    "NextHopType",
    "NextStep",
    "NicTypeInRequest",
    "NicTypeInResponse",
    "NspLinkProvisioningState",
    "NspLinkStatus",
    "NspProvisioningState",
    "OfficeTrafficCategory",
    "Origin",
    "OutputType",
    "OwaspCrsExclusionEntryMatchVariable",
    "OwaspCrsExclusionEntrySelectorMatchOperator",
    "PacketCaptureTargetType",
    "PcError",
    "PcProtocol",
    "PcStatus",
    "PeeringEnforcement",
    "PfsGroup",
    "PreferredIPVersion",
    "PreferredRoutingGateway",
    "PrivateEndpointVNetPolicies",
    "ProbeNoHealthyBackendsBehavior",
    "ProbeProtocol",
    "ProcessorArchitecture",
    "Protocol",
    "ProtocolType",
    "ProvisioningState",
    "PublicIPAddressMigrationPhase",
    "PublicIPAddressSkuName",
    "PublicIPAddressSkuTier",
    "PublicIPPrefixSkuName",
    "PublicIPPrefixSkuTier",
    "PublicIpAddressDnsSettingsDomainNameLabelScope",
    "ResiliencyModel",
    "ResourceIdentityType",
    "RouteFilterRuleType",
    "RouteMapActionType",
    "RouteMapMatchCondition",
    "RouteNextHopType",
    "RoutingRuleDestinationType",
    "RoutingRuleNextHopType",
    "RoutingState",
    "ScopeConnectionState",
    "ScrubbingRuleEntryMatchOperator",
    "ScrubbingRuleEntryMatchVariable",
    "ScrubbingRuleEntryState",
    "SecurityConfigurationRuleAccess",
    "SecurityConfigurationRuleDirection",
    "SecurityConfigurationRuleProtocol",
    "SecurityPartnerProviderConnectionStatus",
    "SecurityProviderName",
    "SecurityRuleAccess",
    "SecurityRuleDirection",
    "SecurityRuleProtocol",
    "SensitivityType",
    "ServiceProviderProvisioningState",
    "Severity",
    "SharingScope",
    "SlotType",
    "SyncMode",
    "SyncRemoteAddressSpace",
    "TransportProtocol",
    "TunnelConnectionStatus",
    "UsageUnit",
    "UseHubGateway",
    "VerbosityLevel",
    "VirtualNetworkEncryptionEnforcement",
    "VirtualNetworkGatewayConnectionMode",
    "VirtualNetworkGatewayConnectionProtocol",
    "VirtualNetworkGatewayConnectionStatus",
    "VirtualNetworkGatewayConnectionType",
    "VirtualNetworkGatewayMigrationPhase",
    "VirtualNetworkGatewayMigrationState",
    "VirtualNetworkGatewayMigrationType",
    "VirtualNetworkGatewaySkuName",
    "VirtualNetworkGatewaySkuTier",
    "VirtualNetworkGatewayType",
    "VirtualNetworkPeeringLevel",
    "VirtualNetworkPeeringState",
    "VirtualNetworkPrivateEndpointNetworkPolicies",
    "VirtualNetworkPrivateLinkServiceNetworkPolicies",
    "VirtualWanSecurityProviderType",
    "VnetLocalRouteOverrideCriteria",
    "VpnAuthenticationType",
    "VpnClientProtocol",
    "VpnConnectionStatus",
    "VpnGatewayGeneration",
    "VpnGatewayTunnelingProtocol",
    "VpnLinkConnectionMode",
    "VpnNatRuleMode",
    "VpnNatRuleType",
    "VpnPolicyMemberAttributeType",
    "VpnType",
    "WebApplicationFirewallAction",
    "WebApplicationFirewallEnabledState",
    "WebApplicationFirewallMatchVariable",
    "WebApplicationFirewallMode",
    "WebApplicationFirewallOperator",
    "WebApplicationFirewallPolicyResourceState",
    "WebApplicationFirewallRuleType",
    "WebApplicationFirewallScrubbingState",
    "WebApplicationFirewallState",
    "WebApplicationFirewallTransform",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 6
# Methods Covered : 6
# Examples Total  : 6
# Examples Tested : 6
# Coverage %      : 100
# ----------------------

#  nat_gateways: 6/6

import unittest

import azure.mgmt.network
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy
import pytest

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    def create_public_ip_addresses(self, group_name, location, public_ip_name):
        # Create PublicIP
        BODY = {
            "location": location,
            "public_ip_allocation_method": "Static",
            "idle_timeout_in_minutes": 4,
            "sku": {"name": "Standard"},
        }
        result = self.mgmt_client.public_ip_addresses.begin_create_or_update(group_name, public_ip_name, BODY)
        return result.result()

    def create_public_ip_prefixes(self, group_name, location, public_ip_prefix_name):
        # Create public IP prefix defaults[put]
        BODY = {"location": location, "prefix_length": "30", "sku": {"name": "Standard"}}
        result = self.mgmt_client.public_ip_prefixes.begin_create_or_update(group_name, public_ip_prefix_name, BODY)
        return result.result()

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name
        NAT_GATEWAY_NAME = "myNatGateway"
        PUBLIC_IP_ADDRESS_NAME = "publicipaddress"
        PUBLIC_IP_PREFIX_NAME = "publicipprefix"

        self.create_public_ip_addresses(RESOURCE_GROUP, AZURE_LOCATION, PUBLIC_IP_ADDRESS_NAME)
        self.create_public_ip_prefixes(RESOURCE_GROUP, AZURE_LOCATION, PUBLIC_IP_PREFIX_NAME)

        # /NatGateways/put/Create nat gateway[put]
        BODY = {
            "location": "eastus",
            "sku": {"name": "Standard"},
            "public_ip_addresses": [
                {
                    "id": "/subscriptions/"
                    + SUBSCRIPTION_ID
                    + "/resourceGroups/"
                    + RESOURCE_GROUP
                    + "/providers/Microsoft.Network/publicIPAddresses/"
                    + PUBLIC_IP_ADDRESS_NAME
                }
            ],
            "public_ip_prefixes": [
                {
                    "id": "/subscriptions/"
                    + SUBSCRIPTION_ID
                    + "/resourceGroups/"
                    + RESOURCE_GROUP
                    + "/providers/Microsoft.Network/publicIPPrefixes/"
                    + PUBLIC_IP_PREFIX_NAME
                }
            ],
        }
        result = self.mgmt_client.nat_gateways.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP, nat_gateway_name=NAT_GATEWAY_NAME, parameters=BODY
        )
        result = result.result()

        # /NatGateways/get/Get nat gateway[get]
        result = self.mgmt_client.nat_gateways.get(
            resource_group_name=RESOURCE_GROUP, nat_gateway_name=NAT_GATEWAY_NAME
        )

        # /NatGateways/get/List nat gateways in resource group[get]
        result = self.mgmt_client.nat_gateways.list(resource_group_name=RESOURCE_GROUP)

        # /NatGateways/get/List all nat gateways[get]
        result = self.mgmt_client.nat_gateways.list_all()

        # /NatGateways/patch/Update nat gateway tags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.nat_gateways.update_tags(
            resource_group_name=RESOURCE_GROUP, nat_gateway_name=NAT_GATEWAY_NAME, parameters=BODY
        )

        # /NatGateways/delete/Delete nat gateway[delete]
        result = self.mgmt_client.nat_gateways.begin_delete(
            resource_group_name=RESOURCE_GROUP, nat_gateway_name=NAT_GATEWAY_NAME
        )
        result = result.result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 21
# Methods Covered : 21
# Examples Total  : 26
# Examples Tested : 26
# Coverage %      : 100
# ----------------------

#  load_balancers:  6/6
#  inbound_nat_rules:  4/4
#  load_balancer_frontend_ip_configurations:  2/2
#  load_balancer_backend_address_pools:  2/2
#  load_balancer_load_balancing_rules:  2/2
#  load_balancer_outbound_rules:  2/2
#  load_balancer_probes:  2/2
#  load_balancer_network_interfaces:  1/1

import unittest

import azure.mgmt.network
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy
import pytest

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    def create_public_ip_address(self, group_name, location, public_ip_address_name):
        # Create public IP address defaults[put]
        BODY = {
            "public_ip_allocation_method": "Static",
            "idle_timeout_in_minutes": 10,
            "public_ip_address_version": "IPv4",
            "location": location,
            "sku": {"name": "Standard"},
        }
        result = self.mgmt_client.public_ip_addresses.begin_create_or_update(group_name, public_ip_address_name, BODY)
        result = result.result()

    def create_virtual_network(self, group_name, location, network_name, subnet_name):

        result = self.mgmt_client.virtual_networks.begin_create_or_update(
            group_name,
            network_name,
            {"location": location, "address_space": {"address_prefixes": ["10.0.0.0/16"]}},
        )
        result_create = result.result()

        async_subnet_creation = self.mgmt_client.subnets.begin_create_or_update(
            group_name, network_name, subnet_name, {"address_prefix": "10.0.0.0/24"}
        )
        subnet_info = async_subnet_creation.result()

        return subnet_info

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name
        VIRTUAL_NETWORK_NAME = "virtualnetwork"
        SUBNET_NAME = "subnet"
        PUBLIC_IP_ADDRESS_NAME = "public_ip_address_name"
        LOAD_BALANCER_NAME = "myLoadBalancer"
        INBOUND_NAT_RULE_NAME = "myInboundNatRule"
        FRONTEND_IPCONFIGURATION_NAME = "myFrontendIpconfiguration"
        BACKEND_ADDRESS_POOL_NAME = "myBackendAddressPool"
        LOAD_BALANCING_RULE_NAME = "myLoadBalancingRule"
        OUTBOUND_RULE_NAME = "myOutboundRule"
        PROBE_NAME = "myProbe"

        # self.create_virtual_network(RESOURCE_GROUP, AZURE_LOCATION, VIRTUAL_NETWORK_NAME, SUBNET_NAME)
        self.create_public_ip_address(RESOURCE_GROUP, AZURE_LOCATION, PUBLIC_IP_ADDRESS_NAME)

        # Create load balancer
        BODY = {
            "location": "eastus",
            "sku": {"name": "Standard"},
            "frontendIPConfigurations": [
                {
                    "name": FRONTEND_IPCONFIGURATION_NAME,
                    # "subnet": {
                    #   "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworks/" + VIRTUAL_NETWORK_NAME + "/subnets/" + SUBNET_NAME
                    # }
                    "public_ip_address": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/publicIPAddresses/"
                        + PUBLIC_IP_ADDRESS_NAME
                    },
                }
            ],
            "backend_address_pools": [{"name": BACKEND_ADDRESS_POOL_NAME}],
            "load_balancing_rules": [
                {
                    "name": LOAD_BALANCING_RULE_NAME,
                    "frontend_ip_configuration": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/loadBalancers/"
                        + LOAD_BALANCER_NAME
                        + "/frontendIPConfigurations/"
                        + FRONTEND_IPCONFIGURATION_NAME
                    },
                    "frontend_port": "80",
                    "backend_port": "80",
                    "enable_floating_ip": True,
                    "idle_timeout_in_minutes": "15",
                    "protocol": "Tcp",
                    "load_distribution": "Default",
                    "disable_outbound_snat": True,
                    "backend_address_pool": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/loadBalancers/"
                        + LOAD_BALANCER_NAME
                        + "/backendAddressPools/"
                        + BACKEND_ADDRESS_POOL_NAME
                    },
                    "probe": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/loadBalancers/"
                        + LOAD_BALANCER_NAME
                        + "/probes/"
                        + PROBE_NAME
                    },
                }
            ],
            "probes": [
                {
                    "name": PROBE_NAME,
                    "protocol": "Http",
                    "port": "80",
                    "request_path": "healthcheck.aspx",
                    "interval_in_seconds": "15",
                    "number_of_probes": "2",
                }
            ],
            "outbound_rules": [
                {
                    "name": OUTBOUND_RULE_NAME,
                    "backend_address_pool": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/loadBalancers/"
                        + LOAD_BALANCER_NAME
                        + "/backendAddressPools/"
                        + BACKEND_ADDRESS_POOL_NAME
                    },
                    "frontend_ip_configurations": [
                        {
                            "id": "/subscriptions/"
                            + SUBSCRIPTION_ID
                            + "/resourceGroups/"
                            + RESOURCE_GROUP
                            + "/providers/Microsoft.Network/loadBalancers/"
                            + LOAD_BALANCER_NAME
                            + "/frontendIPConfigurations/"
                            + FRONTEND_IPCONFIGURATION_NAME
                        }
                    ],
                    "protocol": "All",
                }
            ],
        }
        result = self.mgmt_client.load_balancers.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME, parameters=BODY
        )
        result = result.result()

        # # /LoadBalancers/put/Create load balancer with Standard SKU[put]
        # BODY = {
        #   "location": "eastus",
        #   "sku": {
        #     "name": "Standard"
        #   },
        #   "frontend_ipconfigurations": [
        #     {
        #       "name": "fe-lb",
        #       "properties": {
        #         "subnet": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworksvnetlbsubnetssubnetlb"
        #         }
        #       }
        #     }
        #   ],
        #   "backend_address_pools": [
        #     {
        #       "name": "be-lb"
        #     }
        #   ],
        #   "load_balancing_rules": [
        #     {
        #       "name": "rulelb",
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #         },
        #         "frontend_port": "80",
        #         "backend_port": "80",
        #         "enable_floating_ip": True,
        #         "idle_timeout_in_minutes": "15",
        #         "protocol": "Tcp",
        #         "load_distribution": "Default",
        #         "backend_address_pool": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbbackendAddressPoolsbe-lb"
        #         },
        #         "probe": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbprobesprobe-lb"
        #         }
        #       }
        #     }
        #   ],
        #   "probes": [
        #     {
        #       "name": "probe-lb",
        #       "properties": {
        #         "protocol": "Http",
        #         "port": "80",
        #         "request_path": "healthcheck.aspx",
        #         "interval_in_seconds": "15",
        #         "number_of_probes": "2"
        #       }
        #     }
        #   ],
        #   "inbound_nat_rules": [
        #     {
        #       "name": "in-nat-rule",
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #         },
        #         "frontend_port": "3389",
        #         "backend_port": "3389",
        #         "enable_floating_ip": True,
        #         "idle_timeout_in_minutes": "15",
        #         "protocol": "Tcp"
        #       }
        #     }
        #   ],
        #   "inbound_nat_pools": [],
        #   "outbound_rules": []
        # }
        # result = self.mgmt_client.load_balancers.begin_create_or_update(resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME, parameters=BODY)
        # result = result.result()

        # # /LoadBalancers/put/Create load balancer with Frontend IP in Zone 1[put]
        # BODY = {
        #   "location": "eastus",
        #   "sku": {
        #     "name": "Standard"
        #   },
        #   "frontend_ipconfigurations": [
        #     {
        #       "name": "fe-lb",
        #       "properties": {
        #         "subnet": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworksvnetlbsubnetssubnetlb"
        #         }
        #       },
        #       "zones": [
        #         "1"
        #       ]
        #     }
        #   ],
        #   "backend_address_pools": [
        #     {
        #       "name": "be-lb"
        #     }
        #   ],
        #   "load_balancing_rules": [
        #     {
        #       "name": "rulelb",
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #         },
        #         "frontend_port": "80",
        #         "backend_port": "80",
        #         "enable_floating_ip": True,
        #         "idle_timeout_in_minutes": "15",
        #         "protocol": "Tcp",
        #         "load_distribution": "Default",
        #         "backend_address_pool": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbbackendAddressPoolsbe-lb"
        #         },
        #         "probe": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbprobesprobe-lb"
        #         }
        #       }
        #     }
        #   ],
        #   "probes": [
        #     {
        #       "name": "probe-lb",
        #       "properties": {
        #         "protocol": "Http",
        #         "port": "80",
        #         "request_path": "healthcheck.aspx",
        #         "interval_in_seconds": "15",
        #         "number_of_probes": "2"
        #       }
        #     }
        #   ],
        #   "inbound_nat_rules": [
        #     {
        #       "name": "in-nat-rule",
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #         },
        #         "frontend_port": "3389",
        #         "backend_port": "3389",
        #         "enable_floating_ip": True,
        #         "idle_timeout_in_minutes": "15",
        #         "protocol": "Tcp"
        #       }
        #     }
        #   ],
        #   "inbound_nat_pools": [],
        #   "outbound_rules": []
        # }
        # result = self.mgmt_client.load_balancers.begin_create_or_update(resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME, parameters=BODY)
        # result = result.result()

        # # /LoadBalancers/put/Create load balancer with inbound nat pool[put]
        # BODY = {
        #   "location": "eastus",
        #   "sku": {
        #     "name": "Standard"
        #   },
        #   "frontend_ipconfigurations": [
        #     {
        #       "properties": {
        #         "private_ipallocation_method": "Dynamic",
        #         "subnet": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworkslbvnetsubnetslbsubnet"
        #         }
        #       },
        #       "name": "test",
        #       "zones": [],
        #       "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationstest"
        #     }
        #   ],
        #   "backend_address_pools": [],
        #   "load_balancing_rules": [],
        #   "probes": [],
        #   "inbound_nat_rules": [],
        #   "outbound_rules": [],
        #   "inbound_nat_pools": [
        #     {
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationstest"
        #         },
        #         "protocol": "Tcp",
        #         "frontend_port_range_start": "8080",
        #         "frontend_port_range_end": "8085",
        #         "backend_port": "8888",
        #         "idle_timeout_in_minutes": "10",
        #         "enable_floating_ip": True,
        #         "enable_tcp_reset": True
        #       },
        #       "name": "test",
        #       "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbinboundNatPoolstest"
        #     }
        #   ]
        # }
        # result = self.mgmt_client.load_balancers.begin_create_or_update(resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME, parameters=BODY)
        # result = result.result()

        # # /LoadBalancers/put/Create load balancer with outbound rules[put]
        # BODY = {
        #   "location": "eastus",
        #   "sku": {
        #     "name": "Standard"
        #   },
        #   "frontend_ipconfigurations": [
        #     {
        #       "name": "fe-lb",
        #       "properties": {
        #         "public_ip_address": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/publicIPAddressespip"
        #         }
        #       }
        #     }
        #   ],
        #   "backend_address_pools": [
        #     {
        #       "name": "be-lb"
        #     }
        #   ],
        #   "load_balancing_rules": [
        #     {
        #       "name": "rulelb",
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #         },
        #         "backend_address_pool": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbbackendAddressPoolsbe-lb"
        #         },
        #         "probe": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbprobesprobe-lb"
        #         },
        #         "protocol": "Tcp",
        #         "load_distribution": "Default",
        #         "frontend_port": "80",
        #         "backend_port": "80",
        #         "idle_timeout_in_minutes": "15",
        #         "enable_floating_ip": True,
        #         "disable_outbound_snat": True
        #       }
        #     }
        #   ],
        #   "probes": [
        #     {
        #       "name": "probe-lb",
        #       "properties": {
        #         "protocol": "Http",
        #         "port": "80",
        #         "request_path": "healthcheck.aspx",
        #         "interval_in_seconds": "15",
        #         "number_of_probes": "2"
        #       }
        #     }
        #   ],
        #   "inbound_nat_rules": [
        #     {
        #       "name": "in-nat-rule",
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #         },
        #         "frontend_port": "3389",
        #         "backend_port": "3389",
        #         "enable_floating_ip": True,
        #         "idle_timeout_in_minutes": "15",
        #         "protocol": "Tcp"
        #       }
        #     }
        #   ],
        #   "inbound_nat_pools": [],
        #   "outbound_rules": [
        #     {
        #       "name": "rule1",
        #       "properties": {
        #         "backend_address_pool": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbbackendAddressPoolsbe-lb"
        #         },
        #         "frontend_ipconfigurations": [
        #           {
        #             "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #           }
        #         ],
        #         "protocol": "All"
        #       }
        #     }
        #   ]
        # }
        # result = self.mgmt_client.load_balancers.begin_create_or_update(resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME, parameters=BODY)
        # result = result.result()

        # # /LoadBalancers/put/Create load balancer[put]
        # BODY = {
        #   "location": "eastus",
        #   "frontend_ipconfigurations": [
        #     {
        #       "name": "fe-lb",
        #       "properties": {
        #         "subnet": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworksvnetlbsubnetssubnetlb"
        #         }
        #       }
        #     }
        #   ],
        #   "backend_address_pools": [
        #     {
        #       "name": "be-lb"
        #     }
        #   ],
        #   "load_balancing_rules": [
        #     {
        #       "name": "rulelb",
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #         },
        #         "frontend_port": "80",
        #         "backend_port": "80",
        #         "enable_floating_ip": True,
        #         "idle_timeout_in_minutes": "15",
        #         "protocol": "Tcp",
        #         "enable_tcp_reset": False,
        #         "load_distribution": "Default",
        #         "backend_address_pool": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbbackendAddressPoolsbe-lb"
        #         },
        #         "probe": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbprobesprobe-lb"
        #         }
        #       }
        #     }
        #   ],
        #   "probes": [
        #     {
        #       "name": "probe-lb",
        #       "properties": {
        #         "protocol": "Http",
        #         "port": "80",
        #         "request_path": "healthcheck.aspx",
        #         "interval_in_seconds": "15",
        #         "number_of_probes": "2"
        #       }
        #     }
        #   ],
        #   "inbound_nat_rules": [
        #     {
        #       "name": "in-nat-rule",
        #       "properties": {
        #         "frontend_ipconfiguration": {
        #           "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/loadBalancerslbfrontendIPConfigurationsfe-lb"
        #         },
        #         "frontend_port": "3389",
        #         "backend_port": "3389",
        #         "enable_floating_ip": True,
        #         "idle_timeout_in_minutes": "15",
        #         "protocol": "Tcp",
        #         "enable_tcp_reset": False
        #       }
        #     }
        #   ],
        #   "inbound_nat_pools": []
        # }
        # result = self.mgmt_client.load_balancers.begin_create_or_update(resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME, parameters=BODY)
        # result = result.result()

        # /InboundNatRules/put/InboundNatRuleCreate[put]
        BODY = {
            "protocol": "Tcp",
            "frontend_ip_configuration": {
                "id": "/subscriptions/"
                + SUBSCRIPTION_ID
                + "/resourceGroups/"
                + RESOURCE_GROUP
                + "/providers/Microsoft.Network/loadBalancers/"
                + LOAD_BALANCER_NAME
                + "/frontendIPConfigurations/"
                + FRONTEND_IPCONFIGURATION_NAME
            },
            "frontend_port": "3390",
            "backend_port": "3389",
            "idle_timeout_in_minutes": "4",
            "enable_tcp_reset": False,
            "enable_floating_ip": False,
        }
        result = self.mgmt_client.inbound_nat_rules.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP,
            load_balancer_name=LOAD_BALANCER_NAME,
            inbound_nat_rule_name=INBOUND_NAT_RULE_NAME,
            inbound_nat_rule_parameters=BODY,
        )
        result = result.result()

        # /LoadBalancerFrontendIPConfigurations/get/LoadBalancerFrontendIPConfigurationGet[get]
        result = self.mgmt_client.load_balancer_frontend_ip_configurations.get(
            resource_group_name=RESOURCE_GROUP,
            load_balancer_name=LOAD_BALANCER_NAME,
            frontend_ip_configuration_name=FRONTEND_IPCONFIGURATION_NAME,
        )

        # /LoadBalancerBackendAddressPools/get/LoadBalancerBackendAddressPoolGet[get]
        result = self.mgmt_client.load_balancer_backend_address_pools.get(
            resource_group_name=RESOURCE_GROUP,
            load_balancer_name=LOAD_BALANCER_NAME,
            backend_address_pool_name=BACKEND_ADDRESS_POOL_NAME,
        )

        # /LoadBalancerLoadBalancingRules/get/LoadBalancerLoadBalancingRuleGet[get]
        result = self.mgmt_client.load_balancer_load_balancing_rules.get(
            resource_group_name=RESOURCE_GROUP,
            load_balancer_name=LOAD_BALANCER_NAME,
            load_balancing_rule_name=LOAD_BALANCING_RULE_NAME,
        )

        # /InboundNatRules/get/InboundNatRuleGet[get]
        result = self.mgmt_client.inbound_nat_rules.get(
            resource_group_name=RESOURCE_GROUP,
            load_balancer_name=LOAD_BALANCER_NAME,
            inbound_nat_rule_name=INBOUND_NAT_RULE_NAME,
        )

        # /LoadBalancerOutboundRules/get/LoadBalancerOutboundRuleGet[get]
        result = self.mgmt_client.load_balancer_outbound_rules.get(
            resource_group_name=RESOURCE_GROUP,
            load_balancer_name=LOAD_BALANCER_NAME,
            outbound_rule_name=OUTBOUND_RULE_NAME,
        )

        # /LoadBalancerFrontendIPConfigurations/get/LoadBalancerFrontendIPConfigurationList[get]
        result = self.mgmt_client.load_balancer_frontend_ip_configurations.list(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /LoadBalancerProbes/get/LoadBalancerProbeGet[get]
        result = self.mgmt_client.load_balancer_probes.get(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME, probe_name=PROBE_NAME
        )

        # /LoadBalancerBackendAddressPools/get/LoadBalancerBackendAddressPoolList[get]
        result = self.mgmt_client.load_balancer_backend_address_pools.list(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /LoadBalancerLoadBalancingRules/get/LoadBalancerLoadBalancingRuleList[get]
        result = self.mgmt_client.load_balancer_load_balancing_rules.list(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /LoadBalancerNetworkInterfaces/get/LoadBalancerNetworkInterfaceListVmss[get]
        result = self.mgmt_client.load_balancer_network_interfaces.list(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /LoadBalancerNetworkInterfaces/get/LoadBalancerNetworkInterfaceListSimple[get]
        result = self.mgmt_client.load_balancer_network_interfaces.list(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /InboundNatRules/get/InboundNatRuleList[get]
        result = self.mgmt_client.inbound_nat_rules.list(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /LoadBalancerOutboundRules/get/LoadBalancerOutboundRuleList[get]
        result = self.mgmt_client.load_balancer_outbound_rules.list(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /LoadBalancerProbes/get/LoadBalancerProbeList[get]
        result = self.mgmt_client.load_balancer_probes.list(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /LoadBalancers/get/Get load balancer[get]
        result = self.mgmt_client.load_balancers.get(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )

        # /LoadBalancers/get/List load balancers in resource group[get]
        result = self.mgmt_client.load_balancers.list(resource_group_name=RESOURCE_GROUP)

        # /LoadBalancers/get/List all load balancers[get]
        result = self.mgmt_client.load_balancers.list_all()

        # /LoadBalancers/patch/Update load balancer tags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.load_balancers.update_tags(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME, parameters=BODY
        )

        # /InboundNatRules/delete/InboundNatRuleDelete[delete]
        result = self.mgmt_client.inbound_nat_rules.begin_delete(
            resource_group_name=RESOURCE_GROUP,
            load_balancer_name=LOAD_BALANCER_NAME,
            inbound_nat_rule_name=INBOUND_NAT_RULE_NAME,
        )
        result = result.result()

        # /LoadBalancers/delete/Delete load balancer[delete]
        result = self.mgmt_client.load_balancers.begin_delete(
            resource_group_name=RESOURCE_GROUP, load_balancer_name=LOAD_BALANCER_NAME
        )
        result = result.result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 12
# Methods Covered : 12
# Examples Total  : 15
# Examples Tested : 15
# Coverage %      : 100
# ----------------------

#  public_ip_prefixes: 6/6
#  public_ip_addresses: 6/6

import unittest

import azure.mgmt.network
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy
import pytest


AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SERVICE_NAME = "myapimrndxyz"
        PUBLIC_IPPREFIX_NAME = self.get_resource_name("publicipprefix")
        PUBLIC_IP_ADDRESS_NAME = self.get_resource_name("publicipaddress")

        # # Create public IP prefix allocation method[put]
        # BODY = {
        #   "location": "westus",
        #   "properties": {
        #     "public_ip_address_version": "IPv4",
        #     "prefix_length": "30"
        #   },
        #   "sku": {
        #     "name": "Standard"
        #   }
        # }
        # result = self.mgmt_client.public_ip_prefixes.create_or_update(resource_group.name, PUBLIC_IPPREFIX_NAME, BODY)
        # result = result.result()

        # Create public IP prefix defaults[put]
        BODY = {"location": "westus", "prefix_length": "30", "sku": {"name": "Standard"}}
        result = self.mgmt_client.public_ip_prefixes.begin_create_or_update(
            resource_group.name, PUBLIC_IPPREFIX_NAME, BODY
        )
        result = result.result()

        # Create public IP address defaults[put]
        BODY = {"location": "eastus"}
        result = self.mgmt_client.public_ip_addresses.begin_create_or_update(
            resource_group.name, PUBLIC_IP_ADDRESS_NAME, BODY
        )
        result = result.result()

        # # Create public IP address allocation method[put]
        # BODY = {
        #   "properties": {
        #     "public_ipallocation_method": "Static",
        #     "idle_timeout_in_minutes": "10",
        #     "public_ip_address_version": "IPv4"
        #   },
        #   "sku": {
        #     "name": "Standard"
        #   },
        #   "location": "eastus"
        # }
        # result = self.mgmt_client.public_ip_addresses.create_or_update(resource_group.name, PUBLIC_IP_ADDRESS_NAME, BODY)
        # result = result.result()

        # # Create public IP address DNS[put]
        # BODY = {
        #   "properties": {
        #     "dns_settings": {
        #       "domain_name_label": "dnslbl"
        #     }
        #   },
        #   "location": "eastus"
        # }
        # result = self.mgmt_client.public_ip_addresses.create_or_update(resource_group.name, PUBLIC_IP_ADDRESS_NAME, BODY)
        # result = result.result()

        # Get public IP address[get]
        result = self.mgmt_client.public_ip_addresses.get(resource_group.name, PUBLIC_IP_ADDRESS_NAME)

        # Get public IP prefix[get]
        result = self.mgmt_client.public_ip_prefixes.get(resource_group.name, PUBLIC_IPPREFIX_NAME)

        # List resource group public IP addresses[get]
        result = self.mgmt_client.public_ip_addresses.list(resource_group.name)

        # List resource group public IP prefixes[get]
        result = self.mgmt_client.public_ip_prefixes.list(resource_group.name)

        # List all public IP addresses[get]
        result = self.mgmt_client.public_ip_addresses.list_all()

        # List all public IP prefixes[get]
        result = self.mgmt_client.public_ip_prefixes.list_all()

        # Update public IP address tags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.public_ip_addresses.update_tags(resource_group.name, PUBLIC_IP_ADDRESS_NAME, BODY)

        # Update public IP prefix tags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.public_ip_prefixes.update_tags(resource_group.name, PUBLIC_IPPREFIX_NAME, BODY)

        # Delete public IP address[delete]
        result = self.mgmt_client.public_ip_addresses.begin_delete(resource_group.name, PUBLIC_IP_ADDRESS_NAME)
        result = result.result()

        # Delete public IP prefix[delete]
        result = self.mgmt_client.public_ip_prefixes.begin_delete(resource_group.name, PUBLIC_IPPREFIX_NAME)
        result = result.result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 15
# Methods Covered : 15
# Examples Total  : 15
# Examples Tested : 15
# Coverage %      : 100
# ----------------------

#  network_interfaces: 8/8
#  network_interface_tap_configurations: 0/4 # TODO: need virtual network tap
#  network_interface_ip_configurations:  2/2
#  network_interface_load_balancers:  1/1


import unittest
import pytest

import azure.mgmt.network
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    def create_virtual_network(self, group_name, location, network_name, subnet_name):

        result = self.mgmt_client.virtual_networks.begin_create_or_update(
            group_name,
            network_name,
            {"location": location, "address_space": {"address_prefixes": ["10.0.0.0/16"]}},
        )
        result_create = result.result()

        async_subnet_creation = self.mgmt_client.subnets.begin_create_or_update(
            group_name, network_name, subnet_name, {"address_prefix": "10.0.0.0/24"}
        )
        subnet_info = async_subnet_creation.result()

        return subnet_info

    def create_public_ip_address(self, group_name, location, public_ip_address_name):
        # Create public IP address defaults[put]
        BODY = {"location": location}
        result = self.mgmt_client.public_ip_addresses.begin_create_or_update(group_name, public_ip_address_name, BODY)
        result = result.result()

    def create_vm(self, group_name, location, vm_name, nic_id):
        import azure.mgmt.compute

        compute_client = self.create_mgmt_client(azure.mgmt.compute.ComputeManagementClient)

        # Create a vm with empty data disks.[put]
        BODY = {
            "location": "eastus",
            "hardware_profile": {"vm_size": "Standard_D2_v2"},
            "storage_profile": {
                "image_reference": {
                    "sku": "2016-Datacenter",
                    "publisher": "MicrosoftWindowsServer",
                    "version": "latest",
                    "offer": "WindowsServer",
                },
                "os_disk": {
                    "caching": "ReadWrite",
                    "managed_disk": {"storage_account_type": "Standard_LRS"},
                    "name": "myVMosdisk",
                    "create_option": "FromImage",
                },
                "data_disks": [
                    {"disk_size_gb": "1023", "create_option": "Empty", "lun": "0"},
                    {"disk_size_gb": "1023", "create_option": "Empty", "lun": "1"},
                ],
            },
            "os_profile": {
                "admin_username": "testuser",
                "computer_name": "myVM",
                "admin_password": "Aa1!zyx_",
                "windows_configuration": {"enable_automatic_updates": True},  # need automatic update for reimage
            },
            "network_profile": {"network_interfaces": [{"id": nic_id, "properties": {"primary": True}}]},
        }
        result = compute_client.virtual_machines.begin_create_or_update(group_name, vm_name, BODY)
        result = result.result()

    def delete_vm(self, group_name, vm_name):
        import azure.mgmt.compute

        compute_client = self.create_mgmt_client(azure.mgmt.compute.ComputeManagementClient)
        # Fix when version from 17.1.0 to 18.0.0
        result = compute_client.virtual_machines.begin_delete(group_name, vm_name)
        result = result.result()

    @unittest.skip("skip test")
    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name
        PUBLIC_IP_ADDRESS_NAME = "publicipaddress"
        VIRTUAL_NETWORK_NAME = "virtualnetwork"
        SUBNET_NAME = "subnet"
        VIRTUAL_MACHINE_NAME = "virtualmachine"
        NETWORK_INTERFACE_NAME = "myNetworkInterface"
        TAP_CONFIGURATION_NAME = "myTapConfiguration"
        IP_CONFIGURATION_NAME = "myIpConfiguration"

        self.create_virtual_network(RESOURCE_GROUP, AZURE_LOCATION, VIRTUAL_NETWORK_NAME, SUBNET_NAME)
        self.create_public_ip_address(RESOURCE_GROUP, AZURE_LOCATION, PUBLIC_IP_ADDRESS_NAME)

        # /NetworkInterfaces/put/Create network interface[put]
        BODY = {
            "enable_accelerated_networking": True,
            "ip_configurations": [
                {
                    "name": IP_CONFIGURATION_NAME,
                    "public_ip_address": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/publicIPAddresses/"
                        + PUBLIC_IP_ADDRESS_NAME
                    },
                    "subnet": {
                        "id": "/subscriptions/"
                        + SUBSCRIPTION_ID
                        + "/resourceGroups/"
                        + RESOURCE_GROUP
                        + "/providers/Microsoft.Network/virtualNetworks/"
                        + VIRTUAL_NETWORK_NAME
                        + "/subnets/"
                        + SUBNET_NAME
                    },
                }
            ],
            "location": "eastus",
        }
        result = self.mgmt_client.network_interfaces.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME, parameters=BODY
        )
        interface = result.result()

        if self.is_live:
            self.create_vm(RESOURCE_GROUP, AZURE_LOCATION, VIRTUAL_MACHINE_NAME, interface.id)

        # /NetworkInterfaceTapConfigurations/put/Create Network Interface Tap Configurations[put]
        # BODY = {
        #   "properties": {
        #     "virtual_network_tap": {
        #       "id": "/subscriptions/" + SUBSCRIPTION_ID + "/resourceGroups/" + RESOURCE_GROUP + "/providers/Microsoft.Network/virtualNetworkTapstestvtap"
        #     }
        #   }
        # }
        # result = self.mgmt_client.network_interface_tap_configurations.begin_create_or_update(resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME, tap_configuration_name=TAP_CONFIGURATION_NAME, tap_configuration_parameters=BODY)
        # result = result.result()

        # /NetworkInterfaceTapConfigurations/get/Get Network Interface Tap Configurations[get]
        # result = self.mgmt_client.network_interface_tap_configurations.get(resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME, tap_configuration_name=TAP_CONFIGURATION_NAME)

        # /NetworkInterfaceIPConfigurations/get/NetworkInterfaceIPConfigurationGet[get]
        result = self.mgmt_client.network_interface_ip_configurations.get(
            resource_group_name=RESOURCE_GROUP,
            network_interface_name=NETWORK_INTERFACE_NAME,
            ip_configuration_name=IP_CONFIGURATION_NAME,
        )

        # /NetworkInterfaceTapConfigurations/get/List virtual network tap configurations[get]
        # result = self.mgmt_client.network_interface_tap_configurations.list(resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME)

        # /NetworkInterfaceIPConfigurations/get/NetworkInterfaceIPConfigurationList[get]
        result = self.mgmt_client.network_interface_ip_configurations.list(
            resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME
        )

        # /NetworkInterfaceLoadBalancers/get/NetworkInterfaceLoadBalancerList[get]
        result = self.mgmt_client.network_interface_load_balancers.list(
            resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME
        )

        # /NetworkInterfaces/get/Get network interface[get]
        result = self.mgmt_client.network_interfaces.get(
            resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME
        )

        # /NetworkInterfaces/get/List network interfaces in resource group[get]
        result = self.mgmt_client.network_interfaces.list(resource_group_name=RESOURCE_GROUP)

        # /NetworkInterfaces/get/List all network interfaces[get]
        result = self.mgmt_client.network_interfaces.list_all()

        # /NetworkInterfaces/post/List network interface effective network security groups[post]
        result = self.mgmt_client.network_interfaces.begin_list_effective_network_security_groups(
            resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME
        )
        result = result.result()

        # /NetworkInterfaces/post/Show network interface effective route tables[post]
        result = self.mgmt_client.network_interfaces.begin_get_effective_route_table(
            resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME
        )
        result = result.result()

        # /NetworkInterfaces/patch/Update network interface tags[patch]
        BODY = {"tags": {"tag1": "value1", "tag2": "value2"}}
        result = self.mgmt_client.network_interfaces.update_tags(
            resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME, parameters=BODY
        )

        # /NetworkInterfaceTapConfigurations/delete/Delete tap configuration[delete]
        # result = self.mgmt_client.network_interface_tap_configurations.begin_delete(resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME, tap_configuration_name=TAP_CONFIGURATION_NAME)
        # result = result.result()

        if self.is_live:
            self.delete_vm(RESOURCE_GROUP, VIRTUAL_MACHINE_NAME)

        # /NetworkInterfaces/delete/Delete network interface[delete]
        result = self.mgmt_client.network_interfaces.begin_delete(
            resource_group_name=RESOURCE_GROUP, network_interface_name=NETWORK_INTERFACE_NAME
        )
        result = result.result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------


# TEST SCENARIO COVERAGE
# ----------------------
# Methods Total   : 9
# Methods Covered : 9
# Examples Total  : 12
# Examples Tested : 12
# Coverage %      : 100
# ----------------------

#  firewall_policies: 5/5
#  firewall_policy_rule_groups:  4/4

import unittest
import pytest

import azure.mgmt.network
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


class TestMgmtNetwork(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.network.NetworkManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_network(self, resource_group):

        SUBSCRIPTION_ID = self.get_settings_value("SUBSCRIPTION_ID")
        RESOURCE_GROUP = resource_group.name
        FIREWALL_POLICY_NAME = "myFirewallPolicy"
        RULE_GROUP_NAME = "myRuleGroup"

        # /FirewallPolicies/put/Create FirewallPolicy[put]
        BODY = {"tags": {"key1": "value1"}, "location": "West US", "threat_intel_mode": "Alert"}
        result = self.mgmt_client.firewall_policies.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP, firewall_policy_name=FIREWALL_POLICY_NAME, parameters=BODY
        )
        result = result.result()

        # # /FirewallPolicyRuleGroups/put/Create FirewallPolicyRuleGroup With IpGroups[put]
        # BODY = {
        #   "priority": "110",
        #   "rules": [
        #     {
        #       "rule_type": "FirewallPolicyFilterRule",
        #       "name": "Example-Filter-Rule",
        #       "action": {
        #         "type": "Deny"
        #       },
        #       "rule_conditions": [
        #         {
        #           "rule_condition_type": "NetworkRuleCondition",
        #           "name": "network-condition1",
        #           "ip_protocols": [
        #             "TCP"
        #           ],
        #           "destination_ports": [
        #             "*"
        #           ],
        #           "source_ip_groups": [
        #             "/subscriptions/subid/providers/Microsoft.Network/resourceGroup/rg1/ipGroups/ipGroups1"
        #           ],
        #           "destination_ip_groups": [
        #             "/subscriptions/subid/providers/Microsoft.Network/resourceGroup/rg1/ipGroups/ipGroups2"
        #           ]
        #         }
        #       ]
        #     }
        #   ]
        # }
        # result = self.mgmt_client.firewall_policy_rule_groups.create_or_update(resource_group_name=RESOURCE_GROUP, firewall_policy_name=FIREWALL_POLICY_NAME, rule_group_name=RULE_GROUP_NAME, parameters=BODY)
        # result = result.result()

        # /FirewallPolicyRuleGroups/put/Create FirewallPolicyRuleGroup[put]
        BODY = {
            "priority": "110",
            "rules": [
                {
                    "rule_type": "FirewallPolicyFilterRule",
                    "name": "Example-Filter-Rule",
                    "action": {"type": "Deny"},
                    "rule_conditions": [
                        {
                            "rule_condition_type": "NetworkRuleCondition",
                            "name": "network-condition1",
                            "source_addresses": ["10.1.25.0/24"],
                            "destination_addresses": ["*"],
                            "ip_protocols": ["TCP"],
                            "destination_ports": ["*"],
                        }
                    ],
                }
            ],
        }
        result = self.mgmt_client.firewall_policy_rule_groups.begin_create_or_update(
            resource_group_name=RESOURCE_GROUP,
            firewall_policy_name=FIREWALL_POLICY_NAME,
            rule_group_name=RULE_GROUP_NAME,
            parameters=BODY,
        )
        result = result.result()

        # /FirewallPolicyRuleGroups/get/Get FirewallPolicyRuleGroup With IpGroups[get]
        # result = self.mgmt_client.firewall_policy_rule_groups.get(resource_group_name=RESOURCE_GROUP, firewall_policy_name=FIREWALL_POLICY_NAME, rule_group_name=RULE_GROUP_NAME)

        # /FirewallPolicyRuleGroups/get/Get FirewallPolicyRuleGroup[get]
        result = self.mgmt_client.firewall_policy_rule_groups.get(
            resource_group_name=RESOURCE_GROUP,
            firewall_policy_name=FIREWALL_POLICY_NAME,
            rule_group_name=RULE_GROUP_NAME,
        )

        # /FirewallPolicyRuleGroups/get/List all FirewallPolicyRuleGroups with IpGroups for a given FirewallPolicy[get]
        # result = self.mgmt_client.firewall_policy_rule_groups.list(resource_group_name=RESOURCE_GROUP, firewall_policy_name=FIREWALL_POLICY_NAME)

        # /FirewallPolicyRuleGroups/get/List all FirewallPolicyRuleGroups for a given FirewallPolicy[get]
        result = self.mgmt_client.firewall_policy_rule_groups.list(
            resource_group_name=RESOURCE_GROUP, firewall_policy_name=FIREWALL_POLICY_NAME
        )

        # /FirewallPolicies/get/Get FirewallPolicy[get]
        result = self.mgmt_client.firewall_policies.get(
            resource_group_name=RESOURCE_GROUP, firewall_policy_name=FIREWALL_POLICY_NAME
        )

        # /FirewallPolicies/get/List all Firewall Policies for a given resource group[get]
        result = self.mgmt_client.firewall_policies.list(resource_group_name=RESOURCE_GROUP)

        # /FirewallPolicies/get/List all Firewall Policies for a given subscription[get]
        result = self.mgmt_client.firewall_policies.list_all()

        # /FirewallPolicyRuleGroups/delete/Delete FirewallPolicyRuleGroup[delete]
        result = self.mgmt_client.firewall_policy_rule_groups.begin_delete(
            resource_group_name=RESOURCE_GROUP,
            firewall_policy_name=FIREWALL_POLICY_NAME,
            rule_group_name=RULE_GROUP_NAME,
        )
        result = result.result()

        # /FirewallPolicies/delete/Delete Firewall Policy[delete]
        result = self.mgmt_client.firewall_policies.begin_delete(
            resource_group_name=RESOURCE_GROUP, firewall_policy_name=FIREWALL_POLICY_NAME
        )
        result = result.result()


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()
